# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.user_app import UserApp

class TestUserApp(unittest.TestCase):
    """UserApp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserApp:
        """Test UserApp
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserApp`
        """
        model = UserApp()
        if include_optional:
            return UserApp(
                id = 56,
                app = iblai.models.app.App(
                    name = '', 
                    url = '', 
                    type = '', 
                    metadata = null, 
                    onboarding_required = True, ),
                platform = iblai.models.platform.Platform(
                    key = '', 
                    name = '', 
                    org = '', 
                    lms_url = '', 
                    cms_url = '', 
                    portal_url = '', ),
                subscription = {
                    'key' : null
                    },
                provider = '',
                is_admin = True,
                is_active = True,
                metadata = None,
                onboarding_completed = True,
                free_trial_started = True,
                free_trial_expired = True,
                has_active_subscription = True
            )
        else:
            return UserApp(
                id = 56,
                app = iblai.models.app.App(
                    name = '', 
                    url = '', 
                    type = '', 
                    metadata = null, 
                    onboarding_required = True, ),
                platform = iblai.models.platform.Platform(
                    key = '', 
                    name = '', 
                    org = '', 
                    lms_url = '', 
                    cms_url = '', 
                    portal_url = '', ),
                subscription = {
                    'key' : null
                    },
                provider = '',
                is_admin = True,
                is_active = True,
        )
        """

    def testUserApp(self):
        """Test UserApp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
