# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.career_api import CareerApi


class TestCareerApi(unittest.TestCase):
    """CareerApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CareerApi()

    def tearDown(self) -> None:
        pass

    def test_career_orgs_companies_users_create(self) -> None:
        """Test case for career_orgs_companies_users_create

        """
        pass

    def test_career_orgs_companies_users_destroy(self) -> None:
        """Test case for career_orgs_companies_users_destroy

        """
        pass

    def test_career_orgs_companies_users_retrieve(self) -> None:
        """Test case for career_orgs_companies_users_retrieve

        """
        pass

    def test_career_orgs_companies_users_update(self) -> None:
        """Test case for career_orgs_companies_users_update

        """
        pass

    def test_career_orgs_education_users_create(self) -> None:
        """Test case for career_orgs_education_users_create

        """
        pass

    def test_career_orgs_education_users_destroy(self) -> None:
        """Test case for career_orgs_education_users_destroy

        """
        pass

    def test_career_orgs_education_users_retrieve(self) -> None:
        """Test case for career_orgs_education_users_retrieve

        """
        pass

    def test_career_orgs_education_users_update(self) -> None:
        """Test case for career_orgs_education_users_update

        """
        pass

    def test_career_orgs_experience_users_create(self) -> None:
        """Test case for career_orgs_experience_users_create

        """
        pass

    def test_career_orgs_experience_users_destroy(self) -> None:
        """Test case for career_orgs_experience_users_destroy

        """
        pass

    def test_career_orgs_experience_users_retrieve(self) -> None:
        """Test case for career_orgs_experience_users_retrieve

        """
        pass

    def test_career_orgs_experience_users_update(self) -> None:
        """Test case for career_orgs_experience_users_update

        """
        pass

    def test_career_orgs_institutions_users_create(self) -> None:
        """Test case for career_orgs_institutions_users_create

        """
        pass

    def test_career_orgs_institutions_users_destroy(self) -> None:
        """Test case for career_orgs_institutions_users_destroy

        """
        pass

    def test_career_orgs_institutions_users_retrieve(self) -> None:
        """Test case for career_orgs_institutions_users_retrieve

        """
        pass

    def test_career_orgs_institutions_users_update(self) -> None:
        """Test case for career_orgs_institutions_users_update

        """
        pass

    def test_career_orgs_programs_users_create(self) -> None:
        """Test case for career_orgs_programs_users_create

        """
        pass

    def test_career_orgs_programs_users_destroy(self) -> None:
        """Test case for career_orgs_programs_users_destroy

        """
        pass

    def test_career_orgs_programs_users_retrieve(self) -> None:
        """Test case for career_orgs_programs_users_retrieve

        """
        pass

    def test_career_orgs_programs_users_update(self) -> None:
        """Test case for career_orgs_programs_users_update

        """
        pass

    def test_career_resume_orgs_users_create(self) -> None:
        """Test case for career_resume_orgs_users_create

        """
        pass

    def test_career_resume_orgs_users_retrieve(self) -> None:
        """Test case for career_resume_orgs_users_retrieve

        """
        pass

    def test_career_resume_orgs_users_update(self) -> None:
        """Test case for career_resume_orgs_users_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
