# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.bulk_program_invitation_create import BulkProgramInvitationCreate

class TestBulkProgramInvitationCreate(unittest.TestCase):
    """BulkProgramInvitationCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BulkProgramInvitationCreate:
        """Test BulkProgramInvitationCreate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BulkProgramInvitationCreate`
        """
        model = BulkProgramInvitationCreate()
        if include_optional:
            return BulkProgramInvitationCreate(
                invitation_data = [
                    iblai.models.program_invitation_create.ProgramInvitationCreate(
                        program_key = '', 
                        email = '', 
                        username = '', 
                        active = True, 
                        source = '', 
                        redirect_to = '', 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expired = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        metadata = {
                            'key' : null
                            }, )
                    ],
                platform_key = ''
            )
        else:
            return BulkProgramInvitationCreate(
                invitation_data = [
                    iblai.models.program_invitation_create.ProgramInvitationCreate(
                        program_key = '', 
                        email = '', 
                        username = '', 
                        active = True, 
                        source = '', 
                        redirect_to = '', 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expired = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        metadata = {
                            'key' : null
                            }, )
                    ],
        )
        """

    def testBulkProgramInvitationCreate(self):
        """Test BulkProgramInvitationCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
