# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.paginated_data_set_list import PaginatedDataSetList

class TestPaginatedDataSetList(unittest.TestCase):
    """PaginatedDataSetList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedDataSetList:
        """Test PaginatedDataSetList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedDataSetList`
        """
        model = PaginatedDataSetList()
        if include_optional:
            return PaginatedDataSetList(
                count = 123,
                next = 'http://api.example.org/accounts/?page=4',
                previous = 'http://api.example.org/accounts/?page=2',
                results = [
                    iblai.models.data_set.DataSet(
                        id = '', 
                        platform = {
                            'key' : null
                            }, 
                        name = '', 
                        prompt = '', 
                        source_url = '', 
                        source_file = '', 
                        status = 'pending', 
                        num_data_points = 56, 
                        train_split = 0, 
                        train_file = '', 
                        test_file = '', 
                        retry_attempts = 56, 
                        error_log = '', 
                        date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PaginatedDataSetList(
        )
        """

    def testPaginatedDataSetList(self):
        """Test PaginatedDataSetList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
