# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.value import Value

class TestValue(unittest.TestCase):
    """Value unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Value:
        """Test Value
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Value`
        """
        model = Value()
        if include_optional:
            return Value(
                data = iblai.models.value_data.ValueData(
                    value = 1.337, )
            )
        else:
            return Value(
                data = iblai.models.value_data.ValueData(
                    value = 1.337, ),
        )
        """

    def testValue(self):
        """Test Value"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
