# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.core_api import CoreApi


class TestCoreApi(unittest.TestCase):
    """CoreApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CoreApi()

    def tearDown(self) -> None:
        pass

    def test_core_lti1p3_provider_lti_keys_create(self) -> None:
        """Test case for core_lti1p3_provider_lti_keys_create

        """
        pass

    def test_core_lti1p3_provider_lti_keys_destroy(self) -> None:
        """Test case for core_lti1p3_provider_lti_keys_destroy

        """
        pass

    def test_core_lti1p3_provider_lti_keys_list(self) -> None:
        """Test case for core_lti1p3_provider_lti_keys_list

        """
        pass

    def test_core_lti1p3_provider_lti_keys_retrieve(self) -> None:
        """Test case for core_lti1p3_provider_lti_keys_retrieve

        """
        pass

    def test_core_lti1p3_provider_lti_keys_update(self) -> None:
        """Test case for core_lti1p3_provider_lti_keys_update

        """
        pass

    def test_core_lti1p3_provider_lti_tools_create(self) -> None:
        """Test case for core_lti1p3_provider_lti_tools_create

        """
        pass

    def test_core_lti1p3_provider_lti_tools_destroy(self) -> None:
        """Test case for core_lti1p3_provider_lti_tools_destroy

        """
        pass

    def test_core_lti1p3_provider_lti_tools_list(self) -> None:
        """Test case for core_lti1p3_provider_lti_tools_list

        """
        pass

    def test_core_lti1p3_provider_lti_tools_retrieve(self) -> None:
        """Test case for core_lti1p3_provider_lti_tools_retrieve

        """
        pass

    def test_core_lti1p3_provider_lti_tools_update(self) -> None:
        """Test case for core_lti1p3_provider_lti_tools_update

        """
        pass

    def test_core_orgs_dark_mode_logo_create_create(self) -> None:
        """Test case for core_orgs_dark_mode_logo_create_create

        """
        pass

    def test_core_orgs_dark_mode_logo_retrieve(self) -> None:
        """Test case for core_orgs_dark_mode_logo_retrieve

        """
        pass

    def test_core_orgs_favicon_create_create(self) -> None:
        """Test case for core_orgs_favicon_create_create

        """
        pass

    def test_core_orgs_favicon_retrieve(self) -> None:
        """Test case for core_orgs_favicon_retrieve

        """
        pass

    def test_core_orgs_logo_create_create(self) -> None:
        """Test case for core_orgs_logo_create_create

        """
        pass

    def test_core_orgs_logo_retrieve(self) -> None:
        """Test case for core_orgs_logo_retrieve

        """
        pass

    def test_core_orgs_metadata_partial_update(self) -> None:
        """Test case for core_orgs_metadata_partial_update

        """
        pass

    def test_core_orgs_metadata_retrieve(self) -> None:
        """Test case for core_orgs_metadata_retrieve

        """
        pass

    def test_core_orgs_metadata_update(self) -> None:
        """Test case for core_orgs_metadata_update

        """
        pass

    def test_core_orgs_redirect_tokens_create(self) -> None:
        """Test case for core_orgs_redirect_tokens_create

        """
        pass

    def test_core_orgs_redirect_tokens_delete_destroy(self) -> None:
        """Test case for core_orgs_redirect_tokens_delete_destroy

        """
        pass

    def test_core_orgs_redirect_tokens_retrieve(self) -> None:
        """Test case for core_orgs_redirect_tokens_retrieve

        """
        pass

    def test_core_orgs_thumbnail_create_create(self) -> None:
        """Test case for core_orgs_thumbnail_create_create

        """
        pass

    def test_core_orgs_thumbnail_retrieve(self) -> None:
        """Test case for core_orgs_thumbnail_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
