# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.program_search import ProgramSearch

class TestProgramSearch(unittest.TestCase):
    """ProgramSearch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProgramSearch:
        """Test ProgramSearch
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProgramSearch`
        """
        model = ProgramSearch()
        if include_optional:
            return ProgramSearch(
                course_list = [
                    iblai.models.program_course_position.ProgramCoursePosition(
                        course_id = '', 
                        name = '', 
                        slug = '', 
                        position = 56, )
                    ],
                program_id = '',
                program_key = '',
                name = '',
                enabled = True,
                slug = 'z',
                org = '',
                platform_key = '',
                program_type = '',
                data = None
            )
        else:
            return ProgramSearch(
                course_list = [
                    iblai.models.program_course_position.ProgramCoursePosition(
                        course_id = '', 
                        name = '', 
                        slug = '', 
                        position = 56, )
                    ],
                program_id = '',
                program_key = '',
                platform_key = '',
                program_type = '',
        )
        """

    def testProgramSearch(self):
        """Test ProgramSearch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
