# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.catalog_api import CatalogApi


class TestCatalogApi(unittest.TestCase):
    """CatalogApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CatalogApi()

    def tearDown(self) -> None:
        pass

    def test_catalog_access_requests_course_manage_create(self) -> None:
        """Test case for catalog_access_requests_course_manage_create

        """
        pass

    def test_catalog_access_requests_course_manage_retrieve(self) -> None:
        """Test case for catalog_access_requests_course_manage_retrieve

        """
        pass

    def test_catalog_access_requests_course_request_create(self) -> None:
        """Test case for catalog_access_requests_course_request_create

        """
        pass

    def test_catalog_access_requests_course_request_retrieve(self) -> None:
        """Test case for catalog_access_requests_course_request_retrieve

        """
        pass

    def test_catalog_conditionals_course_eligibility_retrieve(self) -> None:
        """Test case for catalog_conditionals_course_eligibility_retrieve

        """
        pass

    def test_catalog_conditionals_course_prerequisites_manage_bulk_create(self) -> None:
        """Test case for catalog_conditionals_course_prerequisites_manage_bulk_create

        """
        pass

    def test_catalog_conditionals_course_prerequisites_manage_retrieve(self) -> None:
        """Test case for catalog_conditionals_course_prerequisites_manage_retrieve

        """
        pass

    def test_catalog_courses_create(self) -> None:
        """Test case for catalog_courses_create

        """
        pass

    def test_catalog_courses_destroy(self) -> None:
        """Test case for catalog_courses_destroy

        """
        pass

    def test_catalog_courses_list(self) -> None:
        """Test case for catalog_courses_list

        """
        pass

    def test_catalog_eligibility_courses_check_retrieve(self) -> None:
        """Test case for catalog_eligibility_courses_check_retrieve

        """
        pass

    def test_catalog_eligibility_courses_list(self) -> None:
        """Test case for catalog_eligibility_courses_list

        """
        pass

    def test_catalog_enrollment_courses_search_retrieve(self) -> None:
        """Test case for catalog_enrollment_courses_search_retrieve

        """
        pass

    def test_catalog_enrollment_pathways_create(self) -> None:
        """Test case for catalog_enrollment_pathways_create

        """
        pass

    def test_catalog_enrollment_pathways_destroy(self) -> None:
        """Test case for catalog_enrollment_pathways_destroy

        """
        pass

    def test_catalog_enrollment_pathways_retrieve(self) -> None:
        """Test case for catalog_enrollment_pathways_retrieve

        """
        pass

    def test_catalog_enrollment_pathways_search_retrieve(self) -> None:
        """Test case for catalog_enrollment_pathways_search_retrieve

        """
        pass

    def test_catalog_enrollment_pathways_self_create(self) -> None:
        """Test case for catalog_enrollment_pathways_self_create

        """
        pass

    def test_catalog_enrollment_pathways_self_destroy(self) -> None:
        """Test case for catalog_enrollment_pathways_self_destroy

        """
        pass

    def test_catalog_enrollment_programs_create(self) -> None:
        """Test case for catalog_enrollment_programs_create

        """
        pass

    def test_catalog_enrollment_programs_destroy(self) -> None:
        """Test case for catalog_enrollment_programs_destroy

        """
        pass

    def test_catalog_enrollment_programs_retrieve(self) -> None:
        """Test case for catalog_enrollment_programs_retrieve

        """
        pass

    def test_catalog_enrollment_programs_search_retrieve(self) -> None:
        """Test case for catalog_enrollment_programs_search_retrieve

        """
        pass

    def test_catalog_enrollment_programs_self_create(self) -> None:
        """Test case for catalog_enrollment_programs_self_create

        """
        pass

    def test_catalog_enrollment_programs_self_destroy(self) -> None:
        """Test case for catalog_enrollment_programs_self_destroy

        """
        pass

    def test_catalog_increment_create(self) -> None:
        """Test case for catalog_increment_create

        """
        pass

    def test_catalog_increment_retrieve(self) -> None:
        """Test case for catalog_increment_retrieve

        """
        pass

    def test_catalog_invitations_course_blank_create(self) -> None:
        """Test case for catalog_invitations_course_blank_create

        """
        pass

    def test_catalog_invitations_course_bulk_create(self) -> None:
        """Test case for catalog_invitations_course_bulk_create

        """
        pass

    def test_catalog_invitations_course_create(self) -> None:
        """Test case for catalog_invitations_course_create

        """
        pass

    def test_catalog_invitations_course_destroy(self) -> None:
        """Test case for catalog_invitations_course_destroy

        """
        pass

    def test_catalog_invitations_course_redeem_create(self) -> None:
        """Test case for catalog_invitations_course_redeem_create

        """
        pass

    def test_catalog_invitations_course_retrieve(self) -> None:
        """Test case for catalog_invitations_course_retrieve

        """
        pass

    def test_catalog_invitations_platform_blank_create(self) -> None:
        """Test case for catalog_invitations_platform_blank_create

        """
        pass

    def test_catalog_invitations_platform_bulk_create(self) -> None:
        """Test case for catalog_invitations_platform_bulk_create

        """
        pass

    def test_catalog_invitations_platform_check_retrieve(self) -> None:
        """Test case for catalog_invitations_platform_check_retrieve

        """
        pass

    def test_catalog_invitations_platform_create(self) -> None:
        """Test case for catalog_invitations_platform_create

        """
        pass

    def test_catalog_invitations_platform_destroy(self) -> None:
        """Test case for catalog_invitations_platform_destroy

        """
        pass

    def test_catalog_invitations_platform_redeem_create(self) -> None:
        """Test case for catalog_invitations_platform_redeem_create

        """
        pass

    def test_catalog_invitations_platform_retrieve(self) -> None:
        """Test case for catalog_invitations_platform_retrieve

        """
        pass

    def test_catalog_invitations_program_blank_create(self) -> None:
        """Test case for catalog_invitations_program_blank_create

        """
        pass

    def test_catalog_invitations_program_bulk_create(self) -> None:
        """Test case for catalog_invitations_program_bulk_create

        """
        pass

    def test_catalog_invitations_program_create(self) -> None:
        """Test case for catalog_invitations_program_create

        """
        pass

    def test_catalog_invitations_program_destroy(self) -> None:
        """Test case for catalog_invitations_program_destroy

        """
        pass

    def test_catalog_invitations_program_redeem_create(self) -> None:
        """Test case for catalog_invitations_program_redeem_create

        """
        pass

    def test_catalog_invitations_program_retrieve(self) -> None:
        """Test case for catalog_invitations_program_retrieve

        """
        pass

    def test_catalog_licenses_course_assignment_create(self) -> None:
        """Test case for catalog_licenses_course_assignment_create

        """
        pass

    def test_catalog_licenses_course_assignment_destroy(self) -> None:
        """Test case for catalog_licenses_course_assignment_destroy

        """
        pass

    def test_catalog_licenses_course_assignment_group_create(self) -> None:
        """Test case for catalog_licenses_course_assignment_group_create

        """
        pass

    def test_catalog_licenses_course_assignment_group_destroy(self) -> None:
        """Test case for catalog_licenses_course_assignment_group_destroy

        """
        pass

    def test_catalog_licenses_course_assignment_group_retrieve(self) -> None:
        """Test case for catalog_licenses_course_assignment_group_retrieve

        """
        pass

    def test_catalog_licenses_course_assignment_retrieve(self) -> None:
        """Test case for catalog_licenses_course_assignment_retrieve

        """
        pass

    def test_catalog_licenses_course_create_create(self) -> None:
        """Test case for catalog_licenses_course_create_create

        """
        pass

    def test_catalog_licenses_course_retrieve(self) -> None:
        """Test case for catalog_licenses_course_retrieve

        """
        pass

    def test_catalog_licenses_course_update_create(self) -> None:
        """Test case for catalog_licenses_course_update_create

        """
        pass

    def test_catalog_licenses_platform_create_create(self) -> None:
        """Test case for catalog_licenses_platform_create_create

        """
        pass

    def test_catalog_licenses_platform_retrieve(self) -> None:
        """Test case for catalog_licenses_platform_retrieve

        """
        pass

    def test_catalog_licenses_platform_update_create(self) -> None:
        """Test case for catalog_licenses_platform_update_create

        """
        pass

    def test_catalog_licenses_program_assignment_create(self) -> None:
        """Test case for catalog_licenses_program_assignment_create

        """
        pass

    def test_catalog_licenses_program_assignment_destroy(self) -> None:
        """Test case for catalog_licenses_program_assignment_destroy

        """
        pass

    def test_catalog_licenses_program_assignment_group_create(self) -> None:
        """Test case for catalog_licenses_program_assignment_group_create

        """
        pass

    def test_catalog_licenses_program_assignment_group_destroy(self) -> None:
        """Test case for catalog_licenses_program_assignment_group_destroy

        """
        pass

    def test_catalog_licenses_program_assignment_group_retrieve(self) -> None:
        """Test case for catalog_licenses_program_assignment_group_retrieve

        """
        pass

    def test_catalog_licenses_program_assignment_retrieve(self) -> None:
        """Test case for catalog_licenses_program_assignment_retrieve

        """
        pass

    def test_catalog_licenses_program_create_create(self) -> None:
        """Test case for catalog_licenses_program_create_create

        """
        pass

    def test_catalog_licenses_program_retrieve(self) -> None:
        """Test case for catalog_licenses_program_retrieve

        """
        pass

    def test_catalog_licenses_program_update_create(self) -> None:
        """Test case for catalog_licenses_program_update_create

        """
        pass

    def test_catalog_licenses_user_assignment_check_retrieve(self) -> None:
        """Test case for catalog_licenses_user_assignment_check_retrieve

        """
        pass

    def test_catalog_licenses_user_assignment_create(self) -> None:
        """Test case for catalog_licenses_user_assignment_create

        """
        pass

    def test_catalog_licenses_user_assignment_destroy(self) -> None:
        """Test case for catalog_licenses_user_assignment_destroy

        """
        pass

    def test_catalog_licenses_user_assignment_group_create(self) -> None:
        """Test case for catalog_licenses_user_assignment_group_create

        """
        pass

    def test_catalog_licenses_user_assignment_group_destroy(self) -> None:
        """Test case for catalog_licenses_user_assignment_group_destroy

        """
        pass

    def test_catalog_licenses_user_assignment_group_retrieve(self) -> None:
        """Test case for catalog_licenses_user_assignment_group_retrieve

        """
        pass

    def test_catalog_licenses_user_assignment_retrieve(self) -> None:
        """Test case for catalog_licenses_user_assignment_retrieve

        """
        pass

    def test_catalog_licenses_user_create_create(self) -> None:
        """Test case for catalog_licenses_user_create_create

        """
        pass

    def test_catalog_licenses_user_retrieve(self) -> None:
        """Test case for catalog_licenses_user_retrieve

        """
        pass

    def test_catalog_licenses_user_update_create(self) -> None:
        """Test case for catalog_licenses_user_update_create

        """
        pass

    def test_catalog_metadata_choices_retrieve(self) -> None:
        """Test case for catalog_metadata_choices_retrieve

        """
        pass

    def test_catalog_metadata_course_create(self) -> None:
        """Test case for catalog_metadata_course_create

        """
        pass

    def test_catalog_metadata_course_create2(self) -> None:
        """Test case for catalog_metadata_course_create2

        """
        pass

    def test_catalog_metadata_course_public_retrieve(self) -> None:
        """Test case for catalog_metadata_course_public_retrieve

        """
        pass

    def test_catalog_metadata_course_public_retrieve2(self) -> None:
        """Test case for catalog_metadata_course_public_retrieve2

        """
        pass

    def test_catalog_metadata_course_retrieve(self) -> None:
        """Test case for catalog_metadata_course_retrieve

        """
        pass

    def test_catalog_metadata_course_retrieve2(self) -> None:
        """Test case for catalog_metadata_course_retrieve2

        """
        pass

    def test_catalog_metadata_course_search_create(self) -> None:
        """Test case for catalog_metadata_course_search_create

        """
        pass

    def test_catalog_metadata_program_create(self) -> None:
        """Test case for catalog_metadata_program_create

        """
        pass

    def test_catalog_metadata_program_create2(self) -> None:
        """Test case for catalog_metadata_program_create2

        """
        pass

    def test_catalog_metadata_program_public_retrieve(self) -> None:
        """Test case for catalog_metadata_program_public_retrieve

        """
        pass

    def test_catalog_metadata_program_public_retrieve2(self) -> None:
        """Test case for catalog_metadata_program_public_retrieve2

        """
        pass

    def test_catalog_metadata_program_retrieve(self) -> None:
        """Test case for catalog_metadata_program_retrieve

        """
        pass

    def test_catalog_metadata_program_retrieve2(self) -> None:
        """Test case for catalog_metadata_program_retrieve2

        """
        pass

    def test_catalog_milestones_completions_course_catalog_retrieve(self) -> None:
        """Test case for catalog_milestones_completions_course_catalog_retrieve

        """
        pass

    def test_catalog_milestones_completions_course_manage_create(self) -> None:
        """Test case for catalog_milestones_completions_course_manage_create

        """
        pass

    def test_catalog_milestones_completions_course_manage_retrieve(self) -> None:
        """Test case for catalog_milestones_completions_course_manage_retrieve

        """
        pass

    def test_catalog_milestones_completions_pathway_query_retrieve(self) -> None:
        """Test case for catalog_milestones_completions_pathway_query_retrieve

        """
        pass

    def test_catalog_milestones_completions_program_query_retrieve(self) -> None:
        """Test case for catalog_milestones_completions_program_query_retrieve

        """
        pass

    def test_catalog_milestones_completions_resource_manage_create(self) -> None:
        """Test case for catalog_milestones_completions_resource_manage_create

        """
        pass

    def test_catalog_milestones_completions_resource_manage_retrieve(self) -> None:
        """Test case for catalog_milestones_completions_resource_manage_retrieve

        """
        pass

    def test_catalog_milestones_skill_points_block_create(self) -> None:
        """Test case for catalog_milestones_skill_points_block_create

        """
        pass

    def test_catalog_milestones_skill_points_block_retrieve(self) -> None:
        """Test case for catalog_milestones_skill_points_block_retrieve

        """
        pass

    def test_catalog_milestones_skill_points_course_create(self) -> None:
        """Test case for catalog_milestones_skill_points_course_create

        """
        pass

    def test_catalog_milestones_skill_points_course_retrieve(self) -> None:
        """Test case for catalog_milestones_skill_points_course_retrieve

        """
        pass

    def test_catalog_milestones_skill_points_platform_bulk_create(self) -> None:
        """Test case for catalog_milestones_skill_points_platform_bulk_create

        """
        pass

    def test_catalog_milestones_skill_points_platform_create(self) -> None:
        """Test case for catalog_milestones_skill_points_platform_create

        """
        pass

    def test_catalog_milestones_skill_points_platform_destroy(self) -> None:
        """Test case for catalog_milestones_skill_points_platform_destroy

        """
        pass

    def test_catalog_milestones_skill_points_platform_group_create(self) -> None:
        """Test case for catalog_milestones_skill_points_platform_group_create

        """
        pass

    def test_catalog_milestones_skill_points_platform_retrieve(self) -> None:
        """Test case for catalog_milestones_skill_points_platform_retrieve

        """
        pass

    def test_catalog_milestones_skill_points_user_retrieve(self) -> None:
        """Test case for catalog_milestones_skill_points_user_retrieve

        """
        pass

    def test_catalog_pathways_create(self) -> None:
        """Test case for catalog_pathways_create

        """
        pass

    def test_catalog_pathways_destroy(self) -> None:
        """Test case for catalog_pathways_destroy

        """
        pass

    def test_catalog_pathways_list(self) -> None:
        """Test case for catalog_pathways_list

        """
        pass

    def test_catalog_programs_create(self) -> None:
        """Test case for catalog_programs_create

        """
        pass

    def test_catalog_programs_destroy(self) -> None:
        """Test case for catalog_programs_destroy

        """
        pass

    def test_catalog_programs_list(self) -> None:
        """Test case for catalog_programs_list

        """
        pass

    def test_catalog_recommendation_courses_retrieve(self) -> None:
        """Test case for catalog_recommendation_courses_retrieve

        """
        pass

    def test_catalog_resources_create(self) -> None:
        """Test case for catalog_resources_create

        Create or update a resource with optional image upload
        """
        pass

    def test_catalog_resources_destroy(self) -> None:
        """Test case for catalog_resources_destroy

        """
        pass

    def test_catalog_resources_list(self) -> None:
        """Test case for catalog_resources_list

        """
        pass

    def test_catalog_reviews_course_info_retrieve(self) -> None:
        """Test case for catalog_reviews_course_info_retrieve

        """
        pass

    def test_catalog_reviews_course_retrieve(self) -> None:
        """Test case for catalog_reviews_course_retrieve

        """
        pass

    def test_catalog_reviews_course_update_create(self) -> None:
        """Test case for catalog_reviews_course_update_create

        """
        pass

    def test_catalog_reviews_course_update_destroy(self) -> None:
        """Test case for catalog_reviews_course_update_destroy

        """
        pass

    def test_catalog_reviews_program_info_retrieve(self) -> None:
        """Test case for catalog_reviews_program_info_retrieve

        """
        pass

    def test_catalog_reviews_program_retrieve(self) -> None:
        """Test case for catalog_reviews_program_retrieve

        """
        pass

    def test_catalog_reviews_program_update_create(self) -> None:
        """Test case for catalog_reviews_program_update_create

        """
        pass

    def test_catalog_reviews_program_update_destroy(self) -> None:
        """Test case for catalog_reviews_program_update_destroy

        """
        pass

    def test_catalog_roles_create(self) -> None:
        """Test case for catalog_roles_create

        """
        pass

    def test_catalog_roles_desired_create(self) -> None:
        """Test case for catalog_roles_desired_create

        """
        pass

    def test_catalog_roles_desired_retrieve(self) -> None:
        """Test case for catalog_roles_desired_retrieve

        """
        pass

    def test_catalog_roles_public_create(self) -> None:
        """Test case for catalog_roles_public_create

        """
        pass

    def test_catalog_roles_reported_create(self) -> None:
        """Test case for catalog_roles_reported_create

        """
        pass

    def test_catalog_roles_reported_retrieve(self) -> None:
        """Test case for catalog_roles_reported_retrieve

        """
        pass

    def test_catalog_roles_retrieve(self) -> None:
        """Test case for catalog_roles_retrieve

        """
        pass

    def test_catalog_search_programs_create(self) -> None:
        """Test case for catalog_search_programs_create

        """
        pass

    def test_catalog_skills_create(self) -> None:
        """Test case for catalog_skills_create

        """
        pass

    def test_catalog_skills_desired_create(self) -> None:
        """Test case for catalog_skills_desired_create

        """
        pass

    def test_catalog_skills_desired_retrieve(self) -> None:
        """Test case for catalog_skills_desired_retrieve

        """
        pass

    def test_catalog_skills_public_create(self) -> None:
        """Test case for catalog_skills_public_create

        """
        pass

    def test_catalog_skills_reported_create(self) -> None:
        """Test case for catalog_skills_reported_create

        """
        pass

    def test_catalog_skills_reported_retrieve(self) -> None:
        """Test case for catalog_skills_reported_retrieve

        """
        pass

    def test_catalog_skills_retrieve(self) -> None:
        """Test case for catalog_skills_retrieve

        """
        pass

    def test_catalog_suggestions_course_manage_bulk_create(self) -> None:
        """Test case for catalog_suggestions_course_manage_bulk_create

        """
        pass

    def test_catalog_suggestions_course_manage_create(self) -> None:
        """Test case for catalog_suggestions_course_manage_create

        """
        pass

    def test_catalog_suggestions_course_manage_destroy(self) -> None:
        """Test case for catalog_suggestions_course_manage_destroy

        """
        pass

    def test_catalog_suggestions_course_manage_group_create(self) -> None:
        """Test case for catalog_suggestions_course_manage_group_create

        """
        pass

    def test_catalog_suggestions_course_manage_group_destroy(self) -> None:
        """Test case for catalog_suggestions_course_manage_group_destroy

        """
        pass

    def test_catalog_suggestions_course_manage_group_retrieve(self) -> None:
        """Test case for catalog_suggestions_course_manage_group_retrieve

        """
        pass

    def test_catalog_suggestions_course_manage_retrieve(self) -> None:
        """Test case for catalog_suggestions_course_manage_retrieve

        """
        pass

    def test_catalog_suggestions_course_user_retrieve(self) -> None:
        """Test case for catalog_suggestions_course_user_retrieve

        """
        pass

    def test_catalog_suggestions_pathway_manage_bulk_create(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_bulk_create

        """
        pass

    def test_catalog_suggestions_pathway_manage_create(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_create

        """
        pass

    def test_catalog_suggestions_pathway_manage_destroy(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_destroy

        """
        pass

    def test_catalog_suggestions_pathway_manage_group_create(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_group_create

        """
        pass

    def test_catalog_suggestions_pathway_manage_group_destroy(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_group_destroy

        """
        pass

    def test_catalog_suggestions_pathway_manage_group_retrieve(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_group_retrieve

        """
        pass

    def test_catalog_suggestions_pathway_manage_retrieve(self) -> None:
        """Test case for catalog_suggestions_pathway_manage_retrieve

        """
        pass

    def test_catalog_suggestions_pathway_user_retrieve(self) -> None:
        """Test case for catalog_suggestions_pathway_user_retrieve

        """
        pass

    def test_catalog_suggestions_program_manage_bulk_create(self) -> None:
        """Test case for catalog_suggestions_program_manage_bulk_create

        """
        pass

    def test_catalog_suggestions_program_manage_create(self) -> None:
        """Test case for catalog_suggestions_program_manage_create

        """
        pass

    def test_catalog_suggestions_program_manage_destroy(self) -> None:
        """Test case for catalog_suggestions_program_manage_destroy

        """
        pass

    def test_catalog_suggestions_program_manage_group_create(self) -> None:
        """Test case for catalog_suggestions_program_manage_group_create

        """
        pass

    def test_catalog_suggestions_program_manage_group_destroy(self) -> None:
        """Test case for catalog_suggestions_program_manage_group_destroy

        """
        pass

    def test_catalog_suggestions_program_manage_group_retrieve(self) -> None:
        """Test case for catalog_suggestions_program_manage_group_retrieve

        """
        pass

    def test_catalog_suggestions_program_manage_retrieve(self) -> None:
        """Test case for catalog_suggestions_program_manage_retrieve

        """
        pass

    def test_catalog_suggestions_program_user_retrieve(self) -> None:
        """Test case for catalog_suggestions_program_user_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
