# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.notification_preview import NotificationPreview

class TestNotificationPreview(unittest.TestCase):
    """NotificationPreview unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NotificationPreview:
        """Test NotificationPreview
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotificationPreview`
        """
        model = NotificationPreview()
        if include_optional:
            return NotificationPreview(
                template_id = '',
                template_data = iblai.models.notification_template_data.NotificationTemplateData(
                    message_title = '', 
                    message_body = '', ),
                channels = [
                    56
                    ],
                sources = [
                    iblai.models.notification_source.NotificationSource(
                        type = 'email', 
                        data = null, )
                    ],
                context = {
                    'key' : null
                    },
                process_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return NotificationPreview(
                channels = [
                    56
                    ],
                sources = [
                    iblai.models.notification_source.NotificationSource(
                        type = 'email', 
                        data = null, )
                    ],
        )
        """

    def testNotificationPreview(self):
        """Test NotificationPreview"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
