# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_marketing_api import AiMarketingApi


class TestAiMarketingApi(unittest.TestCase):
    """AiMarketingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiMarketingApi()

    def tearDown(self) -> None:
        pass

    def test_ai_marketing_orgs_users_heygen_videos_create(self) -> None:
        """Test case for ai_marketing_orgs_users_heygen_videos_create

        """
        pass

    def test_ai_marketing_orgs_users_heygen_videos_list(self) -> None:
        """Test case for ai_marketing_orgs_users_heygen_videos_list

        """
        pass

    def test_ai_marketing_orgs_users_heygen_videos_retrieve(self) -> None:
        """Test case for ai_marketing_orgs_users_heygen_videos_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
