# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ItemTypeEnum(str, Enum):
    """
    * `course` - Course * `unit` - Unit * `resource` - Resource * `course_unit` - Course and Unit * `course_resource` - Course and Resource * `unit_resource` - Unit and Resource * `all` - Course, Unit, and Resource
    """

    """
    allowed enum values
    """
    COURSE = 'course'
    UNIT = 'unit'
    RESOURCE = 'resource'
    COURSE_UNIT = 'course_unit'
    COURSE_RESOURCE = 'course_resource'
    UNIT_RESOURCE = 'unit_resource'
    ALL = 'all'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ItemTypeEnum from a JSON string"""
        return cls(json.loads(json_str))


