# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.service_api import ServiceApi


class TestServiceApi(unittest.TestCase):
    """ServiceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ServiceApi()

    def tearDown(self) -> None:
        pass

    def test_service_launch_tenant_create(self) -> None:
        """Test case for service_launch_tenant_create

        """
        pass

    def test_service_manage_user_create(self) -> None:
        """Test case for service_manage_user_create

        """
        pass

    def test_service_manage_user_role_create(self) -> None:
        """Test case for service_manage_user_role_create

        """
        pass

    def test_service_orgs_stripe_course_payment_callback_retrieve(self) -> None:
        """Test case for service_orgs_stripe_course_payment_callback_retrieve

        """
        pass

    def test_service_orgs_users_stripe_checkout_session_create(self) -> None:
        """Test case for service_orgs_users_stripe_checkout_session_create

        """
        pass

    def test_service_orgs_users_stripe_customer_portal_create(self) -> None:
        """Test case for service_orgs_users_stripe_customer_portal_create

        """
        pass

    def test_service_orgs_users_stripe_products_manage_create(self) -> None:
        """Test case for service_orgs_users_stripe_products_manage_create

        """
        pass

    def test_service_orgs_users_stripe_products_retrieve(self) -> None:
        """Test case for service_orgs_users_stripe_products_retrieve

        """
        pass

    def test_service_orgs_users_stripe_subscription_renewal_create(self) -> None:
        """Test case for service_orgs_users_stripe_subscription_renewal_create

        """
        pass

    def test_service_orgs_users_stripe_subscriptions_retrieve(self) -> None:
        """Test case for service_orgs_users_stripe_subscriptions_retrieve

        """
        pass

    def test_service_platforms_stripe_context_retrieve(self) -> None:
        """Test case for service_platforms_stripe_context_retrieve

        """
        pass

    def test_service_platforms_stripe_credit_topup_callback_retrieve(self) -> None:
        """Test case for service_platforms_stripe_credit_topup_callback_retrieve

        """
        pass

    def test_service_platforms_stripe_pricing_page_callback_retrieve(self) -> None:
        """Test case for service_platforms_stripe_pricing_page_callback_retrieve

        """
        pass

    def test_service_platforms_stripe_pricing_page_session_retrieve(self) -> None:
        """Test case for service_platforms_stripe_pricing_page_session_retrieve

        """
        pass

    def test_service_stripe_checkout_free_trial_create(self) -> None:
        """Test case for service_stripe_checkout_free_trial_create

        """
        pass

    def test_service_stripe_checkout_retrieve(self) -> None:
        """Test case for service_stripe_checkout_retrieve

        """
        pass

    def test_service_tenant_validation_create(self) -> None:
        """Test case for service_tenant_validation_create

        """
        pass

    def test_service_token_retrieve(self) -> None:
        """Test case for service_token_retrieve

        """
        pass

    def test_service_user_validation_create(self) -> None:
        """Test case for service_user_validation_create

        """
        pass


if __name__ == '__main__':
    unittest.main()
