# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.skills_api import SkillsApi


class TestSkillsApi(unittest.TestCase):
    """SkillsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SkillsApi()

    def tearDown(self) -> None:
        pass

    def test_skills_orgs_skills_list(self) -> None:
        """Test case for skills_orgs_skills_list

        """
        pass

    def test_skills_orgs_skills_percentile_list(self) -> None:
        """Test case for skills_orgs_skills_percentile_list

        """
        pass

    def test_skills_orgs_skills_percentile_retrieve(self) -> None:
        """Test case for skills_orgs_skills_percentile_retrieve

        """
        pass

    def test_skills_orgs_skills_retrieve(self) -> None:
        """Test case for skills_orgs_skills_retrieve

        """
        pass

    def test_skills_orgs_skills_thresholds_create(self) -> None:
        """Test case for skills_orgs_skills_thresholds_create

        """
        pass

    def test_skills_orgs_skills_thresholds_destroy(self) -> None:
        """Test case for skills_orgs_skills_thresholds_destroy

        """
        pass

    def test_skills_orgs_skills_thresholds_partial_update(self) -> None:
        """Test case for skills_orgs_skills_thresholds_partial_update

        """
        pass

    def test_skills_orgs_skills_thresholds_retrieve(self) -> None:
        """Test case for skills_orgs_skills_thresholds_retrieve

        """
        pass

    def test_skills_orgs_skills_users_desired_skills_retrieve(self) -> None:
        """Test case for skills_orgs_skills_users_desired_skills_retrieve

        """
        pass

    def test_skills_orgs_skills_users_point_percentile_retrieve(self) -> None:
        """Test case for skills_orgs_skills_users_point_percentile_retrieve

        """
        pass

    def test_skills_orgs_skills_users_reported_skills_retrieve(self) -> None:
        """Test case for skills_orgs_skills_users_reported_skills_retrieve

        """
        pass

    def test_skills_orgs_skills_users_retrieve(self) -> None:
        """Test case for skills_orgs_skills_users_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
