# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_index_api import AiIndexApi


class TestAiIndexApi(unittest.TestCase):
    """AiIndexApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiIndexApi()

    def tearDown(self) -> None:
        pass

    def test_ai_index_orgs_users_documents_destroy(self) -> None:
        """Test case for ai_index_orgs_users_documents_destroy

        """
        pass

    def test_ai_index_orgs_users_documents_graph_train_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_graph_train_create

        """
        pass

    def test_ai_index_orgs_users_documents_pathways_retrieve(self) -> None:
        """Test case for ai_index_orgs_users_documents_pathways_retrieve

        """
        pass

    def test_ai_index_orgs_users_documents_retrieve(self) -> None:
        """Test case for ai_index_orgs_users_documents_retrieve

        """
        pass

    def test_ai_index_orgs_users_documents_search_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_search_create

        """
        pass

    def test_ai_index_orgs_users_documents_sources_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_sources_create

        """
        pass

    def test_ai_index_orgs_users_documents_tasks_retrieve(self) -> None:
        """Test case for ai_index_orgs_users_documents_tasks_retrieve

        """
        pass

    def test_ai_index_orgs_users_documents_train_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_train_create

        """
        pass

    def test_ai_index_orgs_users_documents_train_retriever_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_train_retriever_create

        """
        pass

    def test_ai_index_orgs_users_documents_train_sessions_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_train_sessions_create

        """
        pass

    def test_ai_index_orgs_users_documents_update(self) -> None:
        """Test case for ai_index_orgs_users_documents_update

        """
        pass

    def test_ai_index_orgs_users_resource_data_scrapped_retrieve(self) -> None:
        """Test case for ai_index_orgs_users_resource_data_scrapped_retrieve

        """
        pass

    def test_ai_index_orgs_users_resource_data_scrapped_retrieve2(self) -> None:
        """Test case for ai_index_orgs_users_resource_data_scrapped_retrieve2

        """
        pass

    def test_ai_index_webhook_scan_create(self) -> None:
        """Test case for ai_index_webhook_scan_create

        """
        pass


if __name__ == '__main__':
    unittest.main()
