# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.per_learner_last_access_data import PerLearnerLastAccessData

class TestPerLearnerLastAccessData(unittest.TestCase):
    """PerLearnerLastAccessData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PerLearnerLastAccessData:
        """Test PerLearnerLastAccessData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PerLearnerLastAccessData`
        """
        model = PerLearnerLastAccessData()
        if include_optional:
            return PerLearnerLastAccessData(
                course_last_accessed = iblai.models.per_learner_course_last_access_data.PerLearnerCourseLastAccessData(
                    course_id = '', 
                    course_name = '', 
                    block_id = '', 
                    block_display_name = '', 
                    course_grade = 1.337, 
                    course_progress = 1.337, 
                    last_accessed = '', ),
                last_accessed = ''
            )
        else:
            return PerLearnerLastAccessData(
        )
        """

    def testPerLearnerLastAccessData(self):
        """Test PerLearnerLastAccessData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
