# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.performance_api import PerformanceApi


class TestPerformanceApi(unittest.TestCase):
    """PerformanceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PerformanceApi()

    def tearDown(self) -> None:
        pass

    def test_performance_orgs_courses_grading_average_retrieve(self) -> None:
        """Test case for performance_orgs_courses_grading_average_retrieve

        """
        pass

    def test_performance_orgs_courses_grading_average_with_cutoff_retrieve(self) -> None:
        """Test case for performance_orgs_courses_grading_average_with_cutoff_retrieve

        """
        pass

    def test_performance_orgs_courses_grading_detail_retrieve(self) -> None:
        """Test case for performance_orgs_courses_grading_detail_retrieve

        """
        pass

    def test_performance_orgs_courses_grading_per_learner_retrieve(self) -> None:
        """Test case for performance_orgs_courses_grading_per_learner_retrieve

        """
        pass

    def test_performance_orgs_courses_grading_summary_retrieve(self) -> None:
        """Test case for performance_orgs_courses_grading_summary_retrieve

        """
        pass

    def test_performance_orgs_grading_average_retrieve(self) -> None:
        """Test case for performance_orgs_grading_average_retrieve

        """
        pass

    def test_performance_orgs_grading_per_course_retrieve(self) -> None:
        """Test case for performance_orgs_grading_per_course_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
