# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.theme_enum import ThemeEnum

class TestThemeEnum(unittest.TestCase):
    """ThemeEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testThemeEnum(self):
        """Test ThemeEnum"""
        # inst = ThemeEnum()

if __name__ == '__main__':
    unittest.main()
