# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.rbac_policy import RbacPolicy

class TestRbacPolicy(unittest.TestCase):
    """RbacPolicy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RbacPolicy:
        """Test RbacPolicy
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RbacPolicy`
        """
        model = RbacPolicy()
        if include_optional:
            return RbacPolicy(
                id = 56,
                role = iblai.models.rbac_base_role.RbacBaseRole(
                    id = 56, 
                    name = '', 
                    platform_key = '', 
                    actions = [
                        ''
                        ], ),
                platform = iblai.models.rbac_platform.RbacPlatform(
                    id = 56, 
                    key = '', 
                    name = '', ),
                resources = [
                    ''
                    ],
                users = [
                    iblai.models.rbac_user.RbacUser(
                        id = 56, 
                        username = '', )
                    ],
                groups = [
                    iblai.models.rbac_policy_group.RbacPolicyGroup(
                        id = 56, 
                        name = '', 
                        unique_id = '', 
                        description = '', )
                    ],
                role_id = 56,
                platform_key = '',
                users_to_add = [
                    56
                    ],
                users_to_remove = [
                    56
                    ],
                groups_to_add = [
                    56
                    ],
                groups_to_remove = [
                    56
                    ]
            )
        else:
            return RbacPolicy(
                id = 56,
                role = iblai.models.rbac_base_role.RbacBaseRole(
                    id = 56, 
                    name = '', 
                    platform_key = '', 
                    actions = [
                        ''
                        ], ),
                platform = iblai.models.rbac_platform.RbacPlatform(
                    id = 56, 
                    key = '', 
                    name = '', ),
                resources = [
                    ''
                    ],
                users = [
                    iblai.models.rbac_user.RbacUser(
                        id = 56, 
                        username = '', )
                    ],
                groups = [
                    iblai.models.rbac_policy_group.RbacPolicyGroup(
                        id = 56, 
                        name = '', 
                        unique_id = '', 
                        description = '', )
                    ],
                role_id = 56,
                platform_key = '',
        )
        """

    def testRbacPolicy(self):
        """Test RbacPolicy"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
