# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.credential import Credential

class TestCredential(unittest.TestCase):
    """Credential unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Credential:
        """Test Credential
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Credential`
        """
        model = Credential()
        if include_optional:
            return Credential(
                entity_id = '',
                name = '',
                name_override = '',
                description = '',
                criteria_url = '',
                criteria_narrative = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                icon_image = '',
                background_image = '',
                thumbnail_image = '',
                catalog_items = [
                    ''
                    ],
                courses = [
                    {
                        'key' : ''
                        }
                    ],
                programs = [
                    {
                        'key' : ''
                        }
                    ],
                issuer_details = {
                    'key' : ''
                    },
                html_template = '',
                css_template = '',
                metadata = None,
                credential_type = '',
                expires = {
                    'key' : 56
                    },
                tags = None,
                signatories = [
                    {
                        'key' : ''
                        }
                    ]
            )
        else:
            return Credential(
                entity_id = '',
                name = '',
                criteria_url = '',
                criteria_narrative = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                icon_image = '',
                background_image = '',
                thumbnail_image = '',
                catalog_items = [
                    ''
                    ],
                courses = [
                    {
                        'key' : ''
                        }
                    ],
                programs = [
                    {
                        'key' : ''
                        }
                    ],
                issuer_details = {
                    'key' : ''
                    },
                credential_type = '',
                expires = {
                    'key' : 56
                    },
                signatories = [
                    {
                        'key' : ''
                        }
                    ],
        )
        """

    def testCredential(self):
        """Test Credential"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
