# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.paginated_retriever_document_embedding_list import PaginatedRetrieverDocumentEmbeddingList

class TestPaginatedRetrieverDocumentEmbeddingList(unittest.TestCase):
    """PaginatedRetrieverDocumentEmbeddingList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedRetrieverDocumentEmbeddingList:
        """Test PaginatedRetrieverDocumentEmbeddingList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedRetrieverDocumentEmbeddingList`
        """
        model = PaginatedRetrieverDocumentEmbeddingList()
        if include_optional:
            return PaginatedRetrieverDocumentEmbeddingList(
                count = 123,
                next = 'http://api.example.org/accounts/?offset=400&limit=100',
                previous = 'http://api.example.org/accounts/?offset=200&limit=100',
                results = [
                    iblai.models.retriever_document_embedding.RetrieverDocumentEmbedding(
                        id = 56, 
                        metadata = null, 
                        document_name = '', 
                        document_type = '', 
                        training_status = null, 
                        pathway = '', 
                        url = '', 
                        tokens = 56, 
                        platform_key = '', 
                        is_trained = True, 
                        access = null, )
                    ]
            )
        else:
            return PaginatedRetrieverDocumentEmbeddingList(
                count = 123,
                results = [
                    iblai.models.retriever_document_embedding.RetrieverDocumentEmbedding(
                        id = 56, 
                        metadata = null, 
                        document_name = '', 
                        document_type = '', 
                        training_status = null, 
                        pathway = '', 
                        url = '', 
                        tokens = 56, 
                        platform_key = '', 
                        is_trained = True, 
                        access = null, )
                    ],
        )
        """

    def testPaginatedRetrieverDocumentEmbeddingList(self):
        """Test PaginatedRetrieverDocumentEmbeddingList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
