# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.notification_builder_api import NotificationBuilderApi


class TestNotificationBuilderApi(unittest.TestCase):
    """NotificationBuilderApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotificationBuilderApi()

    def tearDown(self) -> None:
        pass

    def test_notification_v1_orgs_notification_builder_context_retrieve(self) -> None:
        """Test case for notification_v1_orgs_notification_builder_context_retrieve

        Get notification context data
        """
        pass

    def test_notification_v1_orgs_notification_builder_preview_create(self) -> None:
        """Test case for notification_v1_orgs_notification_builder_preview_create

        Preview notification
        """
        pass

    def test_notification_v1_orgs_notification_builder_recipients_list(self) -> None:
        """Test case for notification_v1_orgs_notification_builder_recipients_list

        Get build recipients
        """
        pass

    def test_notification_v1_orgs_notification_builder_send_create(self) -> None:
        """Test case for notification_v1_orgs_notification_builder_send_create

        Send notification
        """
        pass

    def test_notification_v1_orgs_notification_builder_validate_source_create(self) -> None:
        """Test case for notification_v1_orgs_notification_builder_validate_source_create

        Validate notification source
        """
        pass


if __name__ == '__main__':
    unittest.main()
