# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MediaTypeEnum(str, Enum):
    """
    * `video` - Video * `image` - Image * `document` - Document * `audio` - Audio * `other` - Other
    """

    """
    allowed enum values
    """
    VIDEO = 'video'
    IMAGE = 'image'
    DOCUMENT = 'document'
    AUDIO = 'audio'
    OTHER = 'other'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MediaTypeEnum from a JSON string"""
        return cls(json.loads(json_str))


