# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_analytics_api import AiAnalyticsApi


class TestAiAnalyticsApi(unittest.TestCase):
    """AiAnalyticsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiAnalyticsApi()

    def tearDown(self) -> None:
        pass

    def test_ai_analytics_orgs_users_chat_history_filter_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_chat_history_filter_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_chat_history_list(self) -> None:
        """Test case for ai_analytics_orgs_users_chat_history_list

        """
        pass

    def test_ai_analytics_orgs_users_chat_history_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_chat_history_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_conversation_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_conversation_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_costs_model_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_costs_model_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_costs_model_usage_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_costs_model_usage_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_costs_permentor_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_costs_permentor_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_costs_peruser_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_costs_peruser_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_mentor_detail_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_mentor_detail_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_mentor_summary_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_mentor_summary_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_sentiment_count_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_sentiment_count_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_topics_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_topics_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_topics_summary_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_topics_summary_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_traces_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_traces_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_traces_retrieve2(self) -> None:
        """Test case for ai_analytics_orgs_users_traces_retrieve2

        """
        pass

    def test_ai_analytics_orgs_users_traces_scores_create(self) -> None:
        """Test case for ai_analytics_orgs_users_traces_scores_create

        """
        pass

    def test_ai_analytics_orgs_users_traces_scores_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_traces_scores_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_transcripts_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_transcripts_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_user_feedback_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_user_feedback_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
