# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.patched_prompt import PatchedPrompt

class TestPatchedPrompt(unittest.TestCase):
    """PatchedPrompt unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedPrompt:
        """Test PatchedPrompt
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedPrompt`
        """
        model = PatchedPrompt()
        if include_optional:
            return PatchedPrompt(
                id = 56,
                mentor = '',
                tone = '',
                style = '',
                language = '',
                tags = [
                    56
                    ],
                is_system = True,
                metadata = None,
                category = '',
                prompt = '',
                title = '',
                description = '',
                prompt_visibility = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by = '',
                platform = 56
            )
        else:
            return PatchedPrompt(
        )
        """

    def testPatchedPrompt(self):
        """Test PatchedPrompt"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
