# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_prompt_api import AiPromptApi


class TestAiPromptApi(unittest.TestCase):
    """AiPromptApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiPromptApi()

    def tearDown(self) -> None:
        pass

    def test_ai_prompt_orgs_metadata_create(self) -> None:
        """Test case for ai_prompt_orgs_metadata_create

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_create(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_create

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_destroy

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_destroy2(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_destroy2

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_update(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_update

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_update2(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_update2

        """
        pass

    def test_ai_prompt_orgs_users_chat_memory_status_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_chat_memory_status_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_chat_memory_status_update(self) -> None:
        """Test case for ai_prompt_orgs_users_chat_memory_status_update

        """
        pass

    def test_ai_prompt_orgs_users_languages_create(self) -> None:
        """Test case for ai_prompt_orgs_users_languages_create

        """
        pass

    def test_ai_prompt_orgs_users_languages_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_languages_destroy

        """
        pass

    def test_ai_prompt_orgs_users_languages_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_languages_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_languages_update(self) -> None:
        """Test case for ai_prompt_orgs_users_languages_update

        """
        pass

    def test_ai_prompt_orgs_users_memory_context_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_context_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_memory_context_update(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_context_update

        """
        pass

    def test_ai_prompt_orgs_users_memory_create(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_create

        """
        pass

    def test_ai_prompt_orgs_users_memory_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_destroy

        """
        pass

    def test_ai_prompt_orgs_users_memory_destroy2(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_destroy2

        """
        pass

    def test_ai_prompt_orgs_users_memory_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_memory_status_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_status_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_memory_status_update(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_status_update

        """
        pass

    def test_ai_prompt_orgs_users_memory_update(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_update

        """
        pass

    def test_ai_prompt_orgs_users_metadata_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_metadata_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_prompt_create(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_create

        """
        pass

    def test_ai_prompt_orgs_users_prompt_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_destroy

        """
        pass

    def test_ai_prompt_orgs_users_prompt_list(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_list

        """
        pass

    def test_ai_prompt_orgs_users_prompt_partial_update(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_partial_update

        """
        pass

    def test_ai_prompt_orgs_users_prompt_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_prompt_update(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_update

        """
        pass

    def test_ai_prompt_orgs_users_prompts_category_create(self) -> None:
        """Test case for ai_prompt_orgs_users_prompts_category_create

        """
        pass

    def test_ai_prompt_orgs_users_prompts_category_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_prompts_category_destroy

        """
        pass

    def test_ai_prompt_orgs_users_prompts_category_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_prompts_category_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_sessions_guided_prompts_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_sessions_guided_prompts_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_styles_create(self) -> None:
        """Test case for ai_prompt_orgs_users_styles_create

        """
        pass

    def test_ai_prompt_orgs_users_styles_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_styles_destroy

        """
        pass

    def test_ai_prompt_orgs_users_styles_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_styles_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_styles_update(self) -> None:
        """Test case for ai_prompt_orgs_users_styles_update

        """
        pass

    def test_ai_prompt_orgs_users_tags_create(self) -> None:
        """Test case for ai_prompt_orgs_users_tags_create

        """
        pass

    def test_ai_prompt_orgs_users_tags_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_tags_destroy

        """
        pass

    def test_ai_prompt_orgs_users_tags_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_tags_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_tags_update(self) -> None:
        """Test case for ai_prompt_orgs_users_tags_update

        """
        pass

    def test_ai_prompt_orgs_users_tones_create(self) -> None:
        """Test case for ai_prompt_orgs_users_tones_create

        """
        pass

    def test_ai_prompt_orgs_users_tones_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_tones_destroy

        """
        pass

    def test_ai_prompt_orgs_users_tones_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_tones_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_tones_update(self) -> None:
        """Test case for ai_prompt_orgs_users_tones_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
