# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.platform_license_create import PlatformLicenseCreate

class TestPlatformLicenseCreate(unittest.TestCase):
    """PlatformLicenseCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlatformLicenseCreate:
        """Test PlatformLicenseCreate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlatformLicenseCreate`
        """
        model = PlatformLicenseCreate()
        if include_optional:
            return PlatformLicenseCreate(
                platform_key = '',
                platform_org = '',
                name = '',
                count = 56,
                started = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expired = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                active = True,
                metadata = {
                    'key' : null
                    },
                source = '',
                external_id = '',
                transaction_id = '',
                change_type = 'create'
            )
        else:
            return PlatformLicenseCreate(
                platform_key = '',
        )
        """

    def testPlatformLicenseCreate(self):
        """Test PlatformLicenseCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
