# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_bot_api import AiBotApi


class TestAiBotApi(unittest.TestCase):
    """AiBotApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiBotApi()

    def tearDown(self) -> None:
        pass

    def test_ai_bot_v1_bots_bot_commands_create(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_create

        """
        pass

    def test_ai_bot_v1_bots_bot_commands_destroy(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_destroy

        """
        pass

    def test_ai_bot_v1_bots_bot_commands_list(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_list

        """
        pass

    def test_ai_bot_v1_bots_bot_commands_partial_update(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_partial_update

        """
        pass

    def test_ai_bot_v1_bots_bot_commands_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_retrieve

        """
        pass

    def test_ai_bot_v1_bots_bot_commands_update(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_update

        """
        pass

    def test_ai_bot_v1_bots_bot_create(self) -> None:
        """Test case for ai_bot_v1_bots_bot_create

        """
        pass

    def test_ai_bot_v1_bots_bot_destroy(self) -> None:
        """Test case for ai_bot_v1_bots_bot_destroy

        """
        pass

    def test_ai_bot_v1_bots_bot_list(self) -> None:
        """Test case for ai_bot_v1_bots_bot_list

        """
        pass

    def test_ai_bot_v1_bots_bot_partial_update(self) -> None:
        """Test case for ai_bot_v1_bots_bot_partial_update

        """
        pass

    def test_ai_bot_v1_bots_bot_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_bot_retrieve

        """
        pass

    def test_ai_bot_v1_bots_bot_update(self) -> None:
        """Test case for ai_bot_v1_bots_bot_update

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_create(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_create

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_destroy(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_destroy

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_list(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_list

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_partial_update(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_partial_update

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_retrieve

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_update(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_update

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_create(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_create

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_destroy(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_destroy

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_list(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_list

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_partial_update(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_partial_update

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_retrieve

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_update(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_update

        """
        pass

    def test_ai_bot_v1_bots_webhooks_discord_create(self) -> None:
        """Test case for ai_bot_v1_bots_webhooks_discord_create

        """
        pass

    def test_ai_bot_v1_bots_webhooks_slack_create(self) -> None:
        """Test case for ai_bot_v1_bots_webhooks_slack_create

        """
        pass

    def test_ai_bot_v1_bots_webhooks_webex_create(self) -> None:
        """Test case for ai_bot_v1_bots_webhooks_webex_create

        """
        pass

    def test_ai_bot_v1_bots_webhooks_whatsapp_create(self) -> None:
        """Test case for ai_bot_v1_bots_webhooks_whatsapp_create

        """
        pass

    def test_ai_bot_v1_bots_webhooks_whatsapp_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_webhooks_whatsapp_retrieve

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_create(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_create

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_destroy(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_destroy

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_list(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_list

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_partial_update(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_partial_update

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_retrieve

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_update(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
