# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.orgs_api import OrgsApi


class TestOrgsApi(unittest.TestCase):
    """OrgsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrgsApi()

    def tearDown(self) -> None:
        pass

    def test_orgs_scim_v2_department_members_create(self) -> None:
        """Test case for orgs_scim_v2_department_members_create

        """
        pass

    def test_orgs_scim_v2_department_members_destroy(self) -> None:
        """Test case for orgs_scim_v2_department_members_destroy

        """
        pass

    def test_orgs_scim_v2_department_members_retrieve(self) -> None:
        """Test case for orgs_scim_v2_department_members_retrieve

        """
        pass

    def test_orgs_scim_v2_department_members_retrieve2(self) -> None:
        """Test case for orgs_scim_v2_department_members_retrieve2

        """
        pass

    def test_orgs_scim_v2_department_members_update(self) -> None:
        """Test case for orgs_scim_v2_department_members_update

        """
        pass

    def test_orgs_scim_v2_departments_add_members_create(self) -> None:
        """Test case for orgs_scim_v2_departments_add_members_create

        """
        pass

    def test_orgs_scim_v2_departments_create(self) -> None:
        """Test case for orgs_scim_v2_departments_create

        """
        pass

    def test_orgs_scim_v2_departments_destroy(self) -> None:
        """Test case for orgs_scim_v2_departments_destroy

        """
        pass

    def test_orgs_scim_v2_departments_remove_members_create(self) -> None:
        """Test case for orgs_scim_v2_departments_remove_members_create

        """
        pass

    def test_orgs_scim_v2_departments_retrieve(self) -> None:
        """Test case for orgs_scim_v2_departments_retrieve

        """
        pass

    def test_orgs_scim_v2_departments_retrieve2(self) -> None:
        """Test case for orgs_scim_v2_departments_retrieve2

        """
        pass

    def test_orgs_scim_v2_departments_update(self) -> None:
        """Test case for orgs_scim_v2_departments_update

        """
        pass

    def test_orgs_scim_v2_group_members_create(self) -> None:
        """Test case for orgs_scim_v2_group_members_create

        """
        pass

    def test_orgs_scim_v2_group_members_destroy(self) -> None:
        """Test case for orgs_scim_v2_group_members_destroy

        """
        pass

    def test_orgs_scim_v2_group_members_retrieve(self) -> None:
        """Test case for orgs_scim_v2_group_members_retrieve

        """
        pass

    def test_orgs_scim_v2_group_members_retrieve2(self) -> None:
        """Test case for orgs_scim_v2_group_members_retrieve2

        """
        pass

    def test_orgs_scim_v2_group_members_update(self) -> None:
        """Test case for orgs_scim_v2_group_members_update

        """
        pass

    def test_orgs_scim_v2_groups_add_members_create(self) -> None:
        """Test case for orgs_scim_v2_groups_add_members_create

        """
        pass

    def test_orgs_scim_v2_groups_create(self) -> None:
        """Test case for orgs_scim_v2_groups_create

        """
        pass

    def test_orgs_scim_v2_groups_destroy(self) -> None:
        """Test case for orgs_scim_v2_groups_destroy

        """
        pass

    def test_orgs_scim_v2_groups_remove_members_create(self) -> None:
        """Test case for orgs_scim_v2_groups_remove_members_create

        """
        pass

    def test_orgs_scim_v2_groups_retrieve(self) -> None:
        """Test case for orgs_scim_v2_groups_retrieve

        """
        pass

    def test_orgs_scim_v2_groups_retrieve2(self) -> None:
        """Test case for orgs_scim_v2_groups_retrieve2

        """
        pass

    def test_orgs_scim_v2_groups_update(self) -> None:
        """Test case for orgs_scim_v2_groups_update

        """
        pass

    def test_orgs_scim_v2_users_create(self) -> None:
        """Test case for orgs_scim_v2_users_create

        """
        pass

    def test_orgs_scim_v2_users_destroy(self) -> None:
        """Test case for orgs_scim_v2_users_destroy

        """
        pass

    def test_orgs_scim_v2_users_retrieve(self) -> None:
        """Test case for orgs_scim_v2_users_retrieve

        """
        pass

    def test_orgs_scim_v2_users_retrieve2(self) -> None:
        """Test case for orgs_scim_v2_users_retrieve2

        """
        pass

    def test_orgs_scim_v2_users_update(self) -> None:
        """Test case for orgs_scim_v2_users_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
