# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.paginated_moderation_log_list import PaginatedModerationLogList

class TestPaginatedModerationLogList(unittest.TestCase):
    """PaginatedModerationLogList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedModerationLogList:
        """Test PaginatedModerationLogList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedModerationLogList`
        """
        model = PaginatedModerationLogList()
        if include_optional:
            return PaginatedModerationLogList(
                count = 123,
                next = 'http://api.example.org/accounts/?page=4',
                previous = 'http://api.example.org/accounts/?page=2',
                results = [
                    iblai.models.moderation_log.ModerationLog(
                        id = 56, 
                        username = '', 
                        platform_key = '', 
                        mentor = 56, 
                        prompt = '', 
                        reason = '', 
                        target_system = 'Safety System', 
                        date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PaginatedModerationLogList(
        )
        """

    def testPaginatedModerationLogList(self):
        """Test PaginatedModerationLogList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
