# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.providers_api import ProvidersApi


class TestProvidersApi(unittest.TestCase):
    """ProvidersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProvidersApi()

    def tearDown(self) -> None:
        pass

    def test_providers_apple_associate_account_create(self) -> None:
        """Test case for providers_apple_associate_account_create

        """
        pass

    def test_providers_apple_hook_create(self) -> None:
        """Test case for providers_apple_hook_create

        """
        pass

    def test_providers_apple_subscription_status_create(self) -> None:
        """Test case for providers_apple_subscription_status_create

        """
        pass

    def test_providers_apple_validate_transaction_id_create(self) -> None:
        """Test case for providers_apple_validate_transaction_id_create

        """
        pass

    def test_providers_aws_create_organization_create(self) -> None:
        """Test case for providers_aws_create_organization_create

        """
        pass

    def test_providers_aws_domain_status_retrieve(self) -> None:
        """Test case for providers_aws_domain_status_retrieve

        """
        pass

    def test_providers_aws_launch_tenant_create(self) -> None:
        """Test case for providers_aws_launch_tenant_create

        """
        pass

    def test_providers_aws_sync_domain_records_create(self) -> None:
        """Test case for providers_aws_sync_domain_records_create

        """
        pass

    def test_providers_aws_sync_domain_records_retrieve(self) -> None:
        """Test case for providers_aws_sync_domain_records_retrieve

        """
        pass

    def test_providers_gcp_create_organization_create(self) -> None:
        """Test case for providers_gcp_create_organization_create

        """
        pass

    def test_providers_gcp_create_organization_create2(self) -> None:
        """Test case for providers_gcp_create_organization_create2

        """
        pass

    def test_providers_gcp_hook_create(self) -> None:
        """Test case for providers_gcp_hook_create

        """
        pass

    def test_providers_gcp_launch_tenant_create(self) -> None:
        """Test case for providers_gcp_launch_tenant_create

        """
        pass

    def test_providers_gcp_validate_signup_token_create(self) -> None:
        """Test case for providers_gcp_validate_signup_token_create

        """
        pass

    def test_providers_google_pay_get_account_retrieve(self) -> None:
        """Test case for providers_google_pay_get_account_retrieve

        """
        pass

    def test_providers_google_pay_hook_create(self) -> None:
        """Test case for providers_google_pay_hook_create

        """
        pass

    def test_providers_google_pay_validate_transaction_id_create(self) -> None:
        """Test case for providers_google_pay_validate_transaction_id_create

        """
        pass

    def test_providers_stripe_create_organization_create(self) -> None:
        """Test case for providers_stripe_create_organization_create

        """
        pass


if __name__ == '__main__':
    unittest.main()
