# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.mentor_create import MentorCreate

class TestMentorCreate(unittest.TestCase):
    """MentorCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MentorCreate:
        """Test MentorCreate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MentorCreate`
        """
        model = MentorCreate()
        if include_optional:
            return MentorCreate(
                name = '',
                unique_id = '',
                flow = None,
                slug = 'z',
                platform = '',
                allow_anonymous = True,
                metadata = None,
                enable_moderation = True,
                enable_post_processing_system = True,
                enable_openai_assistant = True,
                enable_total_grounding = True,
                enable_suggested_prompts = True,
                enable_guided_prompts = True,
                google_voice = 56,
                openai_voice = 56,
                guided_prompt_instructions = '',
                categories = [
                    56
                    ],
                proactive_prompt = '',
                moderation_system_prompt = '',
                post_processing_prompt = '',
                moderation_response = '',
                safety_system_prompt = '',
                safety_response = '',
                disable_chathistory = True,
                enable_safety_system = True,
                proactive_response = '',
                mcp_servers = [
                    56
                    ],
                greeting_method = 'proactive_prompt',
                last_accessed_by = 56,
                recently_accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return MentorCreate(
                name = '',
                flow = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testMentorCreate(self):
        """Test MentorCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
