# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.web_resource import WebResource

class TestWebResource(unittest.TestCase):
    """WebResource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebResource:
        """Test WebResource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebResource`
        """
        model = WebResource()
        if include_optional:
            return WebResource(
                content = '',
                title = '',
                image_url = '',
                source = '',
                metadata = None,
                card = iblai.models.web_resource_card.WebResourceCard(
                    title = '', 
                    description = '', 
                    image_url = '', 
                    domain = '', 
                    site_name = '', )
            )
        else:
            return WebResource(
                content = '',
                title = '',
        )
        """

    def testWebResource(self):
        """Test WebResource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
