# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.skill_detail import SkillDetail

class TestSkillDetail(unittest.TestCase):
    """SkillDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SkillDetail:
        """Test SkillDetail
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SkillDetail`
        """
        model = SkillDetail()
        if include_optional:
            return SkillDetail(
                name = '',
                courses = [
                    iblai.models.course_skill.CourseSkill(
                        course_id = '', 
                        skills = [
                            iblai.models.skill.Skill(
                                id = 56, 
                                name = '', )
                            ], )
                    ],
                related_skills = 56
            )
        else:
            return SkillDetail(
                courses = [
                    iblai.models.course_skill.CourseSkill(
                        course_id = '', 
                        skills = [
                            iblai.models.skill.Skill(
                                id = 56, 
                                name = '', )
                            ], )
                    ],
                related_skills = 56,
        )
        """

    def testSkillDetail(self):
        """Test SkillDetail"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
