# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class StateEnum(str, Enum):
    """
    * `pending` - Pending * `running` - Running * `accumulating` - Accumulating * `processing` - Processing * `storing` - Storing * `completed` - Completed * `cancelled` - Cancelled * `error` - Error * `expired` - Expired
    """

    """
    allowed enum values
    """
    PENDING = 'pending'
    RUNNING = 'running'
    ACCUMULATING = 'accumulating'
    PROCESSING = 'processing'
    STORING = 'storing'
    COMPLETED = 'completed'
    CANCELLED = 'cancelled'
    ERROR = 'error'
    EXPIRED = 'expired'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of StateEnum from a JSON string"""
        return cls(json.loads(json_str))


