# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.platform_skill_point_response import PlatformSkillPointResponse

class TestPlatformSkillPointResponse(unittest.TestCase):
    """PlatformSkillPointResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlatformSkillPointResponse:
        """Test PlatformSkillPointResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlatformSkillPointResponse`
        """
        model = PlatformSkillPointResponse()
        if include_optional:
            return PlatformSkillPointResponse(
                results = [
                    {
                        'key' : null
                        }
                    ],
                count = 56,
                next_page = '',
                previous_page = ''
            )
        else:
            return PlatformSkillPointResponse(
                results = [
                    {
                        'key' : null
                        }
                    ],
                count = 56,
                next_page = '',
                previous_page = '',
        )
        """

    def testPlatformSkillPointResponse(self):
        """Test PlatformSkillPointResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
