# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.detailed_grade_subsection import DetailedGradeSubsection

class TestDetailedGradeSubsection(unittest.TestCase):
    """DetailedGradeSubsection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DetailedGradeSubsection:
        """Test DetailedGradeSubsection
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DetailedGradeSubsection`
        """
        model = DetailedGradeSubsection()
        if include_optional:
            return DetailedGradeSubsection(
                display_name = '',
                id = '',
                graded_earned = '',
                graded_possible = '',
                graded_percent = ''
            )
        else:
            return DetailedGradeSubsection(
                display_name = '',
                id = '',
                graded_earned = '',
                graded_possible = '',
                graded_percent = '',
        )
        """

    def testDetailedGradeSubsection(self):
        """Test DetailedGradeSubsection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
