# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.engagement_api import EngagementApi


class TestEngagementApi(unittest.TestCase):
    """EngagementApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EngagementApi()

    def tearDown(self) -> None:
        pass

    def test_engagement_orgs_activity_retrieve(self) -> None:
        """Test case for engagement_orgs_activity_retrieve

        """
        pass

    def test_engagement_orgs_course_completion_over_time_retrieve(self) -> None:
        """Test case for engagement_orgs_course_completion_over_time_retrieve

        """
        pass

    def test_engagement_orgs_course_completion_per_course_retrieve(self) -> None:
        """Test case for engagement_orgs_course_completion_per_course_retrieve

        """
        pass

    def test_engagement_orgs_courses_time_average_retrieve(self) -> None:
        """Test case for engagement_orgs_courses_time_average_retrieve

        """
        pass

    def test_engagement_orgs_courses_time_detail_retrieve(self) -> None:
        """Test case for engagement_orgs_courses_time_detail_retrieve

        """
        pass

    def test_engagement_orgs_courses_time_over_time_retrieve(self) -> None:
        """Test case for engagement_orgs_courses_time_over_time_retrieve

        """
        pass

    def test_engagement_orgs_courses_time_users_detail_retrieve(self) -> None:
        """Test case for engagement_orgs_courses_time_users_detail_retrieve

        """
        pass

    def test_engagement_orgs_courses_time_users_over_time_retrieve(self) -> None:
        """Test case for engagement_orgs_courses_time_users_over_time_retrieve

        """
        pass

    def test_engagement_orgs_courses_time_users_retrieve(self) -> None:
        """Test case for engagement_orgs_courses_time_users_retrieve

        """
        pass

    def test_engagement_orgs_courses_videos_over_time_retrieve(self) -> None:
        """Test case for engagement_orgs_courses_videos_over_time_retrieve

        """
        pass

    def test_engagement_orgs_courses_videos_retrieve(self) -> None:
        """Test case for engagement_orgs_courses_videos_retrieve

        """
        pass

    def test_engagement_orgs_courses_videos_summary_retrieve(self) -> None:
        """Test case for engagement_orgs_courses_videos_summary_retrieve

        """
        pass

    def test_engagement_orgs_courses_videos_users_retrieve(self) -> None:
        """Test case for engagement_orgs_courses_videos_users_retrieve

        """
        pass

    def test_engagement_orgs_time_average_perlearner_percourse_retrieve(self) -> None:
        """Test case for engagement_orgs_time_average_perlearner_percourse_retrieve

        """
        pass

    def test_engagement_orgs_time_average_with_over_time_retrieve(self) -> None:
        """Test case for engagement_orgs_time_average_with_over_time_retrieve

        """
        pass

    def test_engagement_orgs_time_over_time_retrieve(self) -> None:
        """Test case for engagement_orgs_time_over_time_retrieve

        """
        pass

    def test_engagement_orgs_time_per_course_retrieve(self) -> None:
        """Test case for engagement_orgs_time_per_course_retrieve

        """
        pass

    def test_engagement_orgs_videos_over_time_retrieve(self) -> None:
        """Test case for engagement_orgs_videos_over_time_retrieve

        """
        pass

    def test_engagement_orgs_videos_retrieve(self) -> None:
        """Test case for engagement_orgs_videos_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
