# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.token_proxy_output import TokenProxyOutput

class TestTokenProxyOutput(unittest.TestCase):
    """TokenProxyOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TokenProxyOutput:
        """Test TokenProxyOutput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TokenProxyOutput`
        """
        model = TokenProxyOutput()
        if include_optional:
            return TokenProxyOutput(
                data = iblai.models.token_proxy_output_serializer_data.TokenProxyOutputSerializerData(
                    user = null, 
                    axd_token = null, 
                    dm_token = null, )
            )
        else:
            return TokenProxyOutput(
                data = iblai.models.token_proxy_output_serializer_data.TokenProxyOutputSerializerData(
                    user = null, 
                    axd_token = null, 
                    dm_token = null, ),
        )
        """

    def testTokenProxyOutput(self):
        """Test TokenProxyOutput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
