# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.token_proxy_output_serializer_data import TokenProxyOutputSerializerData

class TestTokenProxyOutputSerializerData(unittest.TestCase):
    """TokenProxyOutputSerializerData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TokenProxyOutputSerializerData:
        """Test TokenProxyOutputSerializerData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TokenProxyOutputSerializerData`
        """
        model = TokenProxyOutputSerializerData()
        if include_optional:
            return TokenProxyOutputSerializerData(
                user = iblai.models.token_proxy_user.TokenProxyUser(
                    user_id = 56, 
                    user_email = '', 
                    user_nicename = '', 
                    user_display_name = '', 
                    user_fullname = '', ),
                axd_token = iblai.models.auth_token.AuthToken(
                    token = '', 
                    expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                dm_token = iblai.models.manager_auth_token.ManagerAuthToken(
                    token = '', 
                    expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return TokenProxyOutputSerializerData(
                user = iblai.models.token_proxy_user.TokenProxyUser(
                    user_id = 56, 
                    user_email = '', 
                    user_nicename = '', 
                    user_display_name = '', 
                    user_fullname = '', ),
                axd_token = iblai.models.auth_token.AuthToken(
                    token = '', 
                    expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                dm_token = iblai.models.manager_auth_token.ManagerAuthToken(
                    token = '', 
                    expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testTokenProxyOutputSerializerData(self):
        """Test TokenProxyOutputSerializerData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
