# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.mentor_category_group import MentorCategoryGroup

class TestMentorCategoryGroup(unittest.TestCase):
    """MentorCategoryGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MentorCategoryGroup:
        """Test MentorCategoryGroup
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MentorCategoryGroup`
        """
        model = MentorCategoryGroup()
        if include_optional:
            return MentorCategoryGroup(
                id = 56,
                name = '',
                description = '',
                audience = iblai.models.mentor_audience.MentorAudience(
                    id = 56, 
                    name = '', 
                    description = '', ),
                date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                categories = [
                    iblai.models.mentor_category.MentorCategory(
                        id = 56, 
                        name = '', 
                        description = '', 
                        category_group = 56, 
                        audience = iblai.models.mentor_audience.MentorAudience(
                            id = 56, 
                            name = '', 
                            description = '', ), 
                        audiences = [
                            iblai.models.mentor_audience.MentorAudience(
                                id = 56, 
                                name = '', 
                                description = '', )
                            ], )
                    ],
                audiences = [
                    iblai.models.mentor_audience.MentorAudience(
                        id = 56, 
                        name = '', 
                        description = '', )
                    ]
            )
        else:
            return MentorCategoryGroup(
                id = 56,
                name = '',
                description = '',
                audience = iblai.models.mentor_audience.MentorAudience(
                    id = 56, 
                    name = '', 
                    description = '', ),
                date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                categories = [
                    iblai.models.mentor_category.MentorCategory(
                        id = 56, 
                        name = '', 
                        description = '', 
                        category_group = 56, 
                        audience = iblai.models.mentor_audience.MentorAudience(
                            id = 56, 
                            name = '', 
                            description = '', ), 
                        audiences = [
                            iblai.models.mentor_audience.MentorAudience(
                                id = 56, 
                                name = '', 
                                description = '', )
                            ], )
                    ],
                audiences = [
                    iblai.models.mentor_audience.MentorAudience(
                        id = 56, 
                        name = '', 
                        description = '', )
                    ],
        )
        """

    def testMentorCategoryGroup(self):
        """Test MentorCategoryGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
