# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.revenue_by_product import RevenueByProduct

class TestRevenueByProduct(unittest.TestCase):
    """RevenueByProduct unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RevenueByProduct:
        """Test RevenueByProduct
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RevenueByProduct`
        """
        model = RevenueByProduct()
        if include_optional:
            return RevenueByProduct(
                product_table = [
                    iblai.models.product_table.ProductTable(
                        name = '', 
                        type = '', 
                        total_sales = 1.337, 
                        coupons = 1.337, 
                        net_sales = 1.337, 
                        orders = 56, )
                    ],
                summary = iblai.models.summary.Summary(
                    num_products = 56, 
                    num_orders = 56, 
                    net_revenue = 1.337, 
                    avg_order_value = 1.337, )
            )
        else:
            return RevenueByProduct(
        )
        """

    def testRevenueByProduct(self):
        """Test RevenueByProduct"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
