# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_finetuning_api import AiFinetuningApi


class TestAiFinetuningApi(unittest.TestCase):
    """AiFinetuningApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiFinetuningApi()

    def tearDown(self) -> None:
        pass

    def test_ai_finetuning_v1_org_user_datasets_create(self) -> None:
        """Test case for ai_finetuning_v1_org_user_datasets_create

        """
        pass

    def test_ai_finetuning_v1_org_user_datasets_destroy(self) -> None:
        """Test case for ai_finetuning_v1_org_user_datasets_destroy

        """
        pass

    def test_ai_finetuning_v1_org_user_datasets_list(self) -> None:
        """Test case for ai_finetuning_v1_org_user_datasets_list

        """
        pass

    def test_ai_finetuning_v1_org_user_datasets_partial_update(self) -> None:
        """Test case for ai_finetuning_v1_org_user_datasets_partial_update

        """
        pass

    def test_ai_finetuning_v1_org_user_datasets_retrieve(self) -> None:
        """Test case for ai_finetuning_v1_org_user_datasets_retrieve

        """
        pass

    def test_ai_finetuning_v1_org_user_datasets_update(self) -> None:
        """Test case for ai_finetuning_v1_org_user_datasets_update

        """
        pass

    def test_ai_finetuning_v1_org_user_trainings_create(self) -> None:
        """Test case for ai_finetuning_v1_org_user_trainings_create

        """
        pass

    def test_ai_finetuning_v1_org_user_trainings_destroy(self) -> None:
        """Test case for ai_finetuning_v1_org_user_trainings_destroy

        """
        pass

    def test_ai_finetuning_v1_org_user_trainings_finetuned_models_retrieve(self) -> None:
        """Test case for ai_finetuning_v1_org_user_trainings_finetuned_models_retrieve

        """
        pass

    def test_ai_finetuning_v1_org_user_trainings_list(self) -> None:
        """Test case for ai_finetuning_v1_org_user_trainings_list

        """
        pass

    def test_ai_finetuning_v1_org_user_trainings_partial_update(self) -> None:
        """Test case for ai_finetuning_v1_org_user_trainings_partial_update

        """
        pass

    def test_ai_finetuning_v1_org_user_trainings_retrieve(self) -> None:
        """Test case for ai_finetuning_v1_org_user_trainings_retrieve

        """
        pass

    def test_ai_finetuning_v1_org_user_trainings_update(self) -> None:
        """Test case for ai_finetuning_v1_org_user_trainings_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
