# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.mentor_eval import MentorEval

class TestMentorEval(unittest.TestCase):
    """MentorEval unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MentorEval:
        """Test MentorEval
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MentorEval`
        """
        model = MentorEval()
        if include_optional:
            return MentorEval(
                id = 56,
                mentor = '',
                questions = [
                    iblai.models.mentor_eval_question.MentorEvalQuestion(
                        id = 56, 
                        content = '', 
                        sample_answer = '', )
                    ],
                eval_id = '',
                name = '',
                passing_score = 56,
                evaluation_prompt = '',
                question_set = 56
            )
        else:
            return MentorEval(
                id = 56,
                mentor = '',
                questions = [
                    iblai.models.mentor_eval_question.MentorEvalQuestion(
                        id = 56, 
                        content = '', 
                        sample_answer = '', )
                    ],
        )
        """

    def testMentorEval(self):
        """Test MentorEval"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
