# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.perlearner_api import PerlearnerApi


class TestPerlearnerApi(unittest.TestCase):
    """PerlearnerApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PerlearnerApi()

    def tearDown(self) -> None:
        pass

    def test_perlearner_orgs_users_activity_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_activity_retrieve

        """
        pass

    def test_perlearner_orgs_users_courses_grading_cutoffs_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_courses_grading_cutoffs_retrieve

        """
        pass

    def test_perlearner_orgs_users_courses_grading_detail_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_courses_grading_detail_retrieve

        """
        pass

    def test_perlearner_orgs_users_courses_grading_summary_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_courses_grading_summary_retrieve

        """
        pass

    def test_perlearner_orgs_users_courses_overview_engagement_index_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_courses_overview_engagement_index_retrieve

        """
        pass

    def test_perlearner_orgs_users_courses_overview_grade_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_courses_overview_grade_retrieve

        """
        pass

    def test_perlearner_orgs_users_courses_overview_performance_index_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_courses_overview_performance_index_retrieve

        """
        pass

    def test_perlearner_orgs_users_courses_overview_time_over_time_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_courses_overview_time_over_time_retrieve

        """
        pass

    def test_perlearner_orgs_users_courses_videos_over_time_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_courses_videos_over_time_retrieve

        """
        pass

    def test_perlearner_orgs_users_courses_videos_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_courses_videos_retrieve

        """
        pass

    def test_perlearner_orgs_users_grades_per_course_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_grades_per_course_retrieve

        """
        pass

    def test_perlearner_orgs_users_info_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_info_retrieve

        """
        pass

    def test_perlearner_orgs_users_last_access_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_last_access_retrieve

        """
        pass

    def test_perlearner_orgs_users_overview_engagement_index_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_overview_engagement_index_retrieve

        """
        pass

    def test_perlearner_orgs_users_overview_grades_average_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_overview_grades_average_retrieve

        """
        pass

    def test_perlearner_orgs_users_overview_performance_index_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_overview_performance_index_retrieve

        """
        pass

    def test_perlearner_orgs_users_overview_time_over_time_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_overview_time_over_time_retrieve

        """
        pass

    def test_perlearner_orgs_users_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_retrieve

        """
        pass

    def test_perlearner_orgs_users_videos_over_time_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_videos_over_time_retrieve

        """
        pass

    def test_perlearner_orgs_users_videos_per_course_retrieve(self) -> None:
        """Test case for perlearner_orgs_users_videos_per_course_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
