# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.lti_tool import LtiTool

class TestLtiTool(unittest.TestCase):
    """LtiTool unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LtiTool:
        """Test LtiTool
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LtiTool`
        """
        model = LtiTool()
        if include_optional:
            return LtiTool(
                id = 56,
                title = '',
                issuer = '',
                client_id = '',
                auth_login_url = '',
                auth_token_url = '',
                auth_audience = '',
                key_set_url = '',
                key_set = None,
                tool_key = 56,
                deployment_ids = [
                    ''
                    ],
                platform_key = '',
                launch_gate = iblai.models.lti_launch_gate.LtiLaunchGate(
                    allowed_keys = [
                        ''
                        ], 
                    allowed_courses = [
                        ''
                        ], 
                    allow_all_within_org = True, )
            )
        else:
            return LtiTool(
                id = 56,
                title = '',
                issuer = '',
                client_id = '',
                auth_login_url = '',
                auth_token_url = '',
                tool_key = 56,
                deployment_ids = [
                    ''
                    ],
                platform_key = '',
                launch_gate = iblai.models.lti_launch_gate.LtiLaunchGate(
                    allowed_keys = [
                        ''
                        ], 
                    allowed_courses = [
                        ''
                        ], 
                    allow_all_within_org = True, ),
        )
        """

    def testLtiTool(self):
        """Test LtiTool"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
