# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.new_per_learner_list import NewPerLearnerList

class TestNewPerLearnerList(unittest.TestCase):
    """NewPerLearnerList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NewPerLearnerList:
        """Test NewPerLearnerList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NewPerLearnerList`
        """
        model = NewPerLearnerList()
        if include_optional:
            return NewPerLearnerList(
                data = [
                    iblai.models.new_per_learner_list_data.NewPerLearnerListData(
                        username = '', 
                        user_id = 56, 
                        name = '', 
                        email = '', 
                        courses_enrolled = 56, 
                        courses_completed = 56, 
                        time_spent = '', 
                        pathways_assigned = 56, 
                        pathways_completed = 56, 
                        certificates_earned = 56, 
                        assessments_passed = 56, 
                        skills_earned = 56, 
                        skills_points = 56, 
                        last_login = '', 
                        location = '', )
                    ],
                pagination = iblai.models.pagination.Pagination(
                    total_items = 56, 
                    current_page = 56, 
                    per_page = 56, 
                    total_pages = 56, )
            )
        else:
            return NewPerLearnerList(
                pagination = iblai.models.pagination.Pagination(
                    total_items = 56, 
                    current_page = 56, 
                    per_page = 56, 
                    total_pages = 56, ),
        )
        """

    def testNewPerLearnerList(self):
        """Test NewPerLearnerList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
