# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.stripe_checkout_session_request import StripeCheckoutSessionRequest

class TestStripeCheckoutSessionRequest(unittest.TestCase):
    """StripeCheckoutSessionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StripeCheckoutSessionRequest:
        """Test StripeCheckoutSessionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StripeCheckoutSessionRequest`
        """
        model = StripeCheckoutSessionRequest()
        if include_optional:
            return StripeCheckoutSessionRequest(
                sku = '',
                product = '',
                success_url = '',
                cancel_url = '',
                mode = 'subscription',
                metered = True,
                quantity = 1,
                coupon = '',
                is_free_trial = True,
                trial_days = 1,
                skip_card = True
            )
        else:
            return StripeCheckoutSessionRequest(
                success_url = '',
                cancel_url = '',
        )
        """

    def testStripeCheckoutSessionRequest(self):
        """Test StripeCheckoutSessionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
