# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_account_api import AiAccountApi


class TestAiAccountApi(unittest.TestCase):
    """AiAccountApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiAccountApi()

    def tearDown(self) -> None:
        pass

    def test_ai_account_orgs_credential_create(self) -> None:
        """Test case for ai_account_orgs_credential_create

        """
        pass

    def test_ai_account_orgs_credential_partial_update(self) -> None:
        """Test case for ai_account_orgs_credential_partial_update

        """
        pass

    def test_ai_account_orgs_credential_retrieve(self) -> None:
        """Test case for ai_account_orgs_credential_retrieve

        """
        pass

    def test_ai_account_orgs_integration_credential_create(self) -> None:
        """Test case for ai_account_orgs_integration_credential_create

        """
        pass

    def test_ai_account_orgs_integration_credential_partial_update(self) -> None:
        """Test case for ai_account_orgs_integration_credential_partial_update

        """
        pass

    def test_ai_account_orgs_integration_credential_retrieve(self) -> None:
        """Test case for ai_account_orgs_integration_credential_retrieve

        """
        pass

    def test_ai_account_orgs_platform_metadata_create(self) -> None:
        """Test case for ai_account_orgs_platform_metadata_create

        """
        pass

    def test_ai_account_orgs_platform_metadata_list(self) -> None:
        """Test case for ai_account_orgs_platform_metadata_list

        """
        pass

    def test_ai_account_orgs_platform_metadata_update(self) -> None:
        """Test case for ai_account_orgs_platform_metadata_update

        """
        pass

    def test_ai_account_orgs_tokens_list(self) -> None:
        """Test case for ai_account_orgs_tokens_list

        """
        pass

    def test_ai_account_orgs_use_default_llm_key_create(self) -> None:
        """Test case for ai_account_orgs_use_default_llm_key_create

        """
        pass

    def test_ai_account_orgs_use_free_trial_create(self) -> None:
        """Test case for ai_account_orgs_use_free_trial_create

        """
        pass

    def test_ai_account_orgs_users_default_llm_key_usage_retrieve(self) -> None:
        """Test case for ai_account_orgs_users_default_llm_key_usage_retrieve

        """
        pass

    def test_ai_account_orgs_users_free_trial_list(self) -> None:
        """Test case for ai_account_orgs_users_free_trial_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
