# coding: utf-8

# flake8: noqa
"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from iblai.models.ai_generated_image import AIGeneratedImage
from iblai.models.ai_user_profile_memory_relation import AIUserProfileMemoryRelation
from iblai.models.ai_user_profile_request import AIUserProfileRequest
from iblai.models.api_token_cost import APITokenCost
from iblai.models.aws_tenant_launch_request import AWSTenantLaunchRequest
from iblai.models.acceptance_enum import AcceptanceEnum
from iblai.models.access_enum import AccessEnum
from iblai.models.activate_user_free_trial import ActivateUserFreeTrial
from iblai.models.active_users_data import ActiveUsersData
from iblai.models.active_users_list import ActiveUsersList
from iblai.models.active_users_per_course import ActiveUsersPerCourse
from iblai.models.active_users_per_course_data import ActiveUsersPerCourseData
from iblai.models.activity_api import ActivityAPI
from iblai.models.activity_data import ActivityData
from iblai.models.ai_account_orgs_use_default_llm_key_create200_response import AiAccountOrgsUseDefaultLlmKeyCreate200Response
from iblai.models.ai_account_orgs_users_free_trial_retrieve200_response import AiAccountOrgsUsersFreeTrialRetrieve200Response
from iblai.models.align_mentor_bubble_enum import AlignMentorBubbleEnum
from iblai.models.analytics_overview import AnalyticsOverview
from iblai.models.answer import Answer
from iblai.models.app import App
from iblai.models.apple_subscription_status_request import AppleSubscriptionStatusRequest
from iblai.models.apple_subscription_status_view import AppleSubscriptionStatusView
from iblai.models.apple_verify_transaction_id import AppleVerifyTransactionId
from iblai.models.assertion import Assertion
from iblai.models.associate_account_response import AssociateAccountResponse
from iblai.models.associate_apple_account import AssociateAppleAccount
from iblai.models.assumed_knowledge import AssumedKnowledge
from iblai.models.assumed_knowledge_level import AssumedKnowledgeLevel
from iblai.models.audio_to_text_request import AudioToTextRequest
from iblai.models.audio_to_text_response import AudioToTextResponse
from iblai.models.auth_token import AuthToken
from iblai.models.average import Average
from iblai.models.average_data import AverageData
from iblai.models.average_overtime import AverageOvertime
from iblai.models.avg_course_grade_with_cutoff import AvgCourseGradeWithCutoff
from iblai.models.avg_course_grade_with_cutoff_data import AvgCourseGradeWithCutoffData
from iblai.models.base_error_response import BaseErrorResponse
from iblai.models.base_response import BaseResponse
from iblai.models.blank_course_invitation_create import BlankCourseInvitationCreate
from iblai.models.blank_enum import BlankEnum
from iblai.models.blank_platform_invitation_create import BlankPlatformInvitationCreate
from iblai.models.blank_program_invitation_create import BlankProgramInvitationCreate
from iblai.models.block_skill_point_info_request import BlockSkillPointInfoRequest
from iblai.models.bot import Bot
from iblai.models.bot_command import BotCommand
from iblai.models.bot_create import BotCreate
from iblai.models.bulk_course_invitation_create import BulkCourseInvitationCreate
from iblai.models.bulk_course_invitation_response import BulkCourseInvitationResponse
from iblai.models.bulk_create_assertion import BulkCreateAssertion
from iblai.models.bulk_platform_invitation_create import BulkPlatformInvitationCreate
from iblai.models.bulk_platform_invitation_response import BulkPlatformInvitationResponse
from iblai.models.bulk_program_invitation_create import BulkProgramInvitationCreate
from iblai.models.bulk_program_invitation_response import BulkProgramInvitationResponse
from iblai.models.bulk_suggestion_response import BulkSuggestionResponse
from iblai.models.call_authentication_request import CallAuthenticationRequest
from iblai.models.call_authentication_response import CallAuthenticationResponse
from iblai.models.call_configuration import CallConfiguration
from iblai.models.call_configuration_mode_enum import CallConfigurationModeEnum
from iblai.models.campaign_enablement import CampaignEnablement
from iblai.models.campaign_exclusion import CampaignExclusion
from iblai.models.catalog_auto_increment_response import CatalogAutoIncrementResponse
from iblai.models.catalog_auto_increment_update_request import CatalogAutoIncrementUpdateRequest
from iblai.models.celery_heartbeat import CeleryHeartbeat
from iblai.models.celery_heartbeat_fail import CeleryHeartbeatFail
from iblai.models.celery_heartbeat_fail_status_enum import CeleryHeartbeatFailStatusEnum
from iblai.models.celery_heartbeat_status_enum import CeleryHeartbeatStatusEnum
from iblai.models.chat_history import ChatHistory
from iblai.models.chat_history_filter_data import ChatHistoryFilterData
from iblai.models.chat_history_filter_user import ChatHistoryFilterUser
from iblai.models.chat_history_item import ChatHistoryItem
from iblai.models.chat_history_session_id import ChatHistorySessionId
from iblai.models.chat_session_request import ChatSessionRequest
from iblai.models.chat_session_response import ChatSessionResponse
from iblai.models.check_document_training_status import CheckDocumentTrainingStatus
from iblai.models.company import Company
from iblai.models.component_block import ComponentBlock
from iblai.models.component_block_type_enum import ComponentBlockTypeEnum
from iblai.models.context_response import ContextResponse
from iblai.models.conversation_message import ConversationMessage
from iblai.models.conversation_rating import ConversationRating
from iblai.models.conversation_summary import ConversationSummary
from iblai.models.conversation_volume import ConversationVolume
from iblai.models.conversations import Conversations
from iblai.models.cost import Cost
from iblai.models.cost_per_tenant import CostPerTenant
from iblai.models.count import Count
from iblai.models.count_data import CountData
from iblai.models.course import Course
from iblai.models.course_access_request_create import CourseAccessRequestCreate
from iblai.models.course_access_request_detail import CourseAccessRequestDetail
from iblai.models.course_access_request_status_response import CourseAccessRequestStatusResponse
from iblai.models.course_access_request_update import CourseAccessRequestUpdate
from iblai.models.course_completion import CourseCompletion
from iblai.models.course_completion_per_course import CourseCompletionPerCourse
from iblai.models.course_completion_per_course_data import CourseCompletionPerCourseData
from iblai.models.course_completion_summary_data_overtime import CourseCompletionSummaryDataOvertime
from iblai.models.course_completion_summary_overtime import CourseCompletionSummaryOvertime
from iblai.models.course_create_update import CourseCreateUpdate
from iblai.models.course_creation_task import CourseCreationTask
from iblai.models.course_creation_task_file import CourseCreationTaskFile
from iblai.models.course_creation_task_status_enum import CourseCreationTaskStatusEnum
from iblai.models.course_delete_response import CourseDeleteResponse
from iblai.models.course_enrollment_search_response import CourseEnrollmentSearchResponse
from iblai.models.course_grade_detail_block import CourseGradeDetailBlock
from iblai.models.course_grade_detail_sub_section import CourseGradeDetailSubSection
from iblai.models.course_grade_summary import CourseGradeSummary
from iblai.models.course_grade_summary_data import CourseGradeSummaryData
from iblai.models.course_grading_detail import CourseGradingDetail
from iblai.models.course_grading_detail_data import CourseGradingDetailData
from iblai.models.course_group_suggestion_create import CourseGroupSuggestionCreate
from iblai.models.course_group_suggestion_detail import CourseGroupSuggestionDetail
from iblai.models.course_invitation_create import CourseInvitationCreate
from iblai.models.course_invitation_detail import CourseInvitationDetail
from iblai.models.course_invitation_redemption import CourseInvitationRedemption
from iblai.models.course_license_assignment_create import CourseLicenseAssignmentCreate
from iblai.models.course_license_assignment_detail import CourseLicenseAssignmentDetail
from iblai.models.course_license_create import CourseLicenseCreate
from iblai.models.course_license_detail import CourseLicenseDetail
from iblai.models.course_license_group_assignment_create import CourseLicenseGroupAssignmentCreate
from iblai.models.course_license_group_assignment_detail import CourseLicenseGroupAssignmentDetail
from iblai.models.course_license_update import CourseLicenseUpdate
from iblai.models.course_metadata_search_request import CourseMetadataSearchRequest
from iblai.models.course_metadata_update_request import CourseMetadataUpdateRequest
from iblai.models.course_point import CoursePoint
from iblai.models.course_review_info_response import CourseReviewInfoResponse
from iblai.models.course_review_paginated_response import CourseReviewPaginatedResponse
from iblai.models.course_review_request import CourseReviewRequest
from iblai.models.course_review_response import CourseReviewResponse
from iblai.models.course_skill import CourseSkill
from iblai.models.course_skill_point_info_request import CourseSkillPointInfoRequest
from iblai.models.course_suggestion_bulk_create import CourseSuggestionBulkCreate
from iblai.models.course_suggestion_create import CourseSuggestionCreate
from iblai.models.course_suggestion_detail import CourseSuggestionDetail
from iblai.models.credential import Credential
from iblai.models.credential_request import CredentialRequest
from iblai.models.crontab_schedule import CrontabSchedule
from iblai.models.custom_instruction_response import CustomInstructionResponse
from iblai.models.data_set import DataSet
from iblai.models.data_set_create import DataSetCreate
from iblai.models.data_set_platform_value import DataSetPlatformValue
from iblai.models.data_set_status_enum import DataSetStatusEnum
from iblai.models.date_range import DateRange
from iblai.models.desired_role import DesiredRole
from iblai.models.desired_role_create_update_request import DesiredRoleCreateUpdateRequest
from iblai.models.desired_skill import DesiredSkill
from iblai.models.desired_skill_create_update_request import DesiredSkillCreateUpdateRequest
from iblai.models.detailed_grade_subsection import DetailedGradeSubsection
from iblai.models.detailed_grade_view import DetailedGradeView
from iblai.models.detailed_grade_view_data import DetailedGradeViewData
from iblai.models.discord_config import DiscordConfig
from iblai.models.discord_user_config import DiscordUserConfig
from iblai.models.discord_webhook import DiscordWebhook
from iblai.models.document import Document
from iblai.models.document_facet import DocumentFacet
from iblai.models.document_search_response import DocumentSearchResponse
from iblai.models.document_settings_response import DocumentSettingsResponse
from iblai.models.education import Education
from iblai.models.edx_course import EdxCourse
from iblai.models.edx_signal_receiver_request import EdxSignalReceiverRequest
from iblai.models.elevenlabs_custom_voice import ElevenlabsCustomVoice
from iblai.models.elevenlabs_custom_voice_response import ElevenlabsCustomVoiceResponse
from iblai.models.email_prompt_detail import EmailPromptDetail
from iblai.models.email_prompt_list import EmailPromptList
from iblai.models.email_prompt_summary import EmailPromptSummary
from iblai.models.engagement_per_course import EngagementPerCourse
from iblai.models.engagement_per_course_data import EngagementPerCourseData
from iblai.models.enrollments import Enrollments
from iblai.models.enrollments_data import EnrollmentsData
from iblai.models.enrollments_per_user import EnrollmentsPerUser
from iblai.models.enrollments_per_user_data import EnrollmentsPerUserData
from iblai.models.error_response import ErrorResponse
from iblai.models.experience import Experience
from iblai.models.float_over_time import FloatOverTime
from iblai.models.free_usage_count import FreeUsageCount
from iblai.models.full_course import FullCourse
from iblai.models.gcp_tenant_launch_request import GCPTenantLaunchRequest
from iblai.models.global_catalog_search_response import GlobalCatalogSearchResponse
from iblai.models.google_pay_account_response import GooglePayAccountResponse
from iblai.models.google_pay_account_response_status_enum import GooglePayAccountResponseStatusEnum
from iblai.models.google_pay_verify_token import GooglePayVerifyToken
from iblai.models.grading_per_user import GradingPerUser
from iblai.models.grading_per_user_data import GradingPerUserData
from iblai.models.greeting_method_enum import GreetingMethodEnum
from iblai.models.group_list import GroupList
from iblai.models.group_list_data import GroupListData
from iblai.models.guided_prompts_response import GuidedPromptsResponse
from iblai.models.heygen_marketing_video_detail import HeygenMarketingVideoDetail
from iblai.models.heygen_marketing_video_list import HeygenMarketingVideoList
from iblai.models.heygen_template_request import HeygenTemplateRequest
from iblai.models.heygen_template_response_single import HeygenTemplateResponseSingle
from iblai.models.heygen_video_detail import HeygenVideoDetail
from iblai.models.heygen_video_request import HeygenVideoRequest
from iblai.models.iblai_platform_meta import IBLAIPlatformMeta
from iblai.models.iblai_platform_meta_request import IBLAIPlatformMetaRequest
from iblai.models.iblai_platform_meta_update_request import IBLAIPlatformMetaUpdateRequest
from iblai.models.image_upload import ImageUpload
from iblai.models.input_question import InputQuestion
from iblai.models.institution import Institution
from iblai.models.institution_type_enum import InstitutionTypeEnum
from iblai.models.integration_credential import IntegrationCredential
from iblai.models.intial_question_answer import IntialQuestionAnswer
from iblai.models.issuer import Issuer
from iblai.models.issuer_authority import IssuerAuthority
from iblai.models.item_type_enum import ItemTypeEnum
from iblai.models.job_run import JobRun
from iblai.models.kind_enum import KindEnum
from iblai.models.llm_credential_request import LLMCredentialRequest
from iblai.models.llm_credential_response import LLMCredentialResponse
from iblai.models.llm_model_for_tenant import LLMModelForTenant
from iblai.models.llm_question import LLMQuestion
from iblai.models.llm_response import LLMResponse
from iblai.models.llm_traces_list_response import LLMTracesListResponse
from iblai.models.languages_view import LanguagesView
from iblai.models.launcher_view_post_request import LauncherViewPostRequest
from iblai.models.learner_information_api import LearnerInformationAPI
from iblai.models.learner_information_api_data import LearnerInformationAPIData
from iblai.models.link_course_request import LinkCourseRequest
from iblai.models.link_course_response import LinkCourseResponse
from iblai.models.llm_provider_enum import LlmProviderEnum
from iblai.models.lti_key import LtiKey
from iblai.models.lti_launch_gate import LtiLaunchGate
from iblai.models.lti_tool import LtiTool
from iblai.models.mcp_server import MCPServer
from iblai.models.manager_auth_token import ManagerAuthToken
from iblai.models.mark_all_read_request import MarkAllReadRequest
from iblai.models.mark_all_read_response import MarkAllReadResponse
from iblai.models.media_resource import MediaResource
from iblai.models.media_type_enum import MediaTypeEnum
from iblai.models.memory_component_data import MemoryComponentData
from iblai.models.memory_component_memory import MemoryComponentMemory
from iblai.models.memory_component_memory_detail import MemoryComponentMemoryDetail
from iblai.models.memory_component_response import MemoryComponentResponse
from iblai.models.memory_progress import MemoryProgress
from iblai.models.memory_status_request_view import MemoryStatusRequestView
from iblai.models.memory_status_view import MemoryStatusView
from iblai.models.mentor import Mentor
from iblai.models.mentor_audience import MentorAudience
from iblai.models.mentor_category import MentorCategory
from iblai.models.mentor_category_create import MentorCategoryCreate
from iblai.models.mentor_category_group import MentorCategoryGroup
from iblai.models.mentor_category_group_create import MentorCategoryGroupCreate
from iblai.models.mentor_create import MentorCreate
from iblai.models.mentor_custom_voice import MentorCustomVoice
from iblai.models.mentor_custom_voice_response import MentorCustomVoiceResponse
from iblai.models.mentor_data import MentorData
from iblai.models.mentor_detail_analytics import MentorDetailAnalytics
from iblai.models.mentor_eval import MentorEval
from iblai.models.mentor_eval_question import MentorEvalQuestion
from iblai.models.mentor_eval_question_request import MentorEvalQuestionRequest
from iblai.models.mentor_eval_report import MentorEvalReport
from iblai.models.mentor_eval_request import MentorEvalRequest
from iblai.models.mentor_facet import MentorFacet
from iblai.models.mentor_fork import MentorFork
from iblai.models.mentor_from_template_request import MentorFromTemplateRequest
from iblai.models.mentor_from_template_with_setting_request import MentorFromTemplateWithSettingRequest
from iblai.models.mentor_memory_settings_request import MentorMemorySettingsRequest
from iblai.models.mentor_memory_settings_response import MentorMemorySettingsResponse
from iblai.models.mentor_metadata import MentorMetadata
from iblai.models.mentor_scenario import MentorScenario
from iblai.models.mentor_scenario_prompt import MentorScenarioPrompt
from iblai.models.mentor_search_response import MentorSearchResponse
from iblai.models.mentor_session import MentorSession
from iblai.models.mentor_settings import MentorSettings
from iblai.models.mentor_settings_mentor_visibility import MentorSettingsMentorVisibility
from iblai.models.mentor_settings_public import MentorSettingsPublic
from iblai.models.mentor_settings_request import MentorSettingsRequest
from iblai.models.mentor_visibility_enum import MentorVisibilityEnum
from iblai.models.mentor_wizard import MentorWizard
from iblai.models.message_statistics import MessageStatistics
from iblai.models.message_status import MessageStatus
from iblai.models.message_view import MessageView
from iblai.models.message_view_request import MessageViewRequest
from iblai.models.message_view_updat_response import MessageViewUpdatResponse
from iblai.models.metadata import Metadata
from iblai.models.metric_change import MetricChange
from iblai.models.model_cost import ModelCost
from iblai.models.moderation_log import ModerationLog
from iblai.models.net_revenue_over_time import NetRevenueOverTime
from iblai.models.new_per_learner_list import NewPerLearnerList
from iblai.models.new_per_learner_list_data import NewPerLearnerListData
from iblai.models.no_chat_messages_found import NoChatMessagesFound
from iblai.models.notification import Notification
from iblai.models.notification_count import NotificationCount
from iblai.models.notification_preview import NotificationPreview
from iblai.models.notification_source import NotificationSource
from iblai.models.notification_source_type_enum import NotificationSourceTypeEnum
from iblai.models.notification_status_enum import NotificationStatusEnum
from iblai.models.notification_template_data import NotificationTemplateData
from iblai.models.notification_v1_campaigns_unsubscribe_retrieve200_response import NotificationV1CampaignsUnsubscribeRetrieve200Response
from iblai.models.null_enum import NullEnum
from iblai.models.onboarding_status_update import OnboardingStatusUpdate
from iblai.models.order import Order
from iblai.models.over_time import OverTime
from iblai.models.over_time_with_total import OverTimeWithTotal
from iblai.models.overtime_meta import OvertimeMeta
from iblai.models.overtime_with_change_info import OvertimeWithChangeInfo
from iblai.models.page_content import PageContent
from iblai.models.paginated_ai_generated_image_list import PaginatedAIGeneratedImageList
from iblai.models.paginated_assertions_response import PaginatedAssertionsResponse
from iblai.models.paginated_conversations_list import PaginatedConversationsList
from iblai.models.paginated_course_access_request import PaginatedCourseAccessRequest
from iblai.models.paginated_course_creation_task_file_list import PaginatedCourseCreationTaskFileList
from iblai.models.paginated_course_creation_task_list import PaginatedCourseCreationTaskList
from iblai.models.paginated_course_group_suggestion import PaginatedCourseGroupSuggestion
from iblai.models.paginated_course_invitation import PaginatedCourseInvitation
from iblai.models.paginated_course_license import PaginatedCourseLicense
from iblai.models.paginated_course_license_assignment import PaginatedCourseLicenseAssignment
from iblai.models.paginated_course_license_group_assignment import PaginatedCourseLicenseGroupAssignment
from iblai.models.paginated_course_suggestion import PaginatedCourseSuggestion
from iblai.models.paginated_data_set_list import PaginatedDataSetList
from iblai.models.paginated_edx_course_list import PaginatedEdxCourseList
from iblai.models.paginated_email_prompt_list_list import PaginatedEmailPromptListList
from iblai.models.paginated_heygen_marketing_video_list_list import PaginatedHeygenMarketingVideoListList
from iblai.models.paginated_heygen_template_response_single_list import PaginatedHeygenTemplateResponseSingleList
from iblai.models.paginated_job_run_list import PaginatedJobRunList
from iblai.models.paginated_mcp_server_list import PaginatedMCPServerList
from iblai.models.paginated_mentor_list import PaginatedMentorList
from iblai.models.paginated_moderation_log_list import PaginatedModerationLogList
from iblai.models.paginated_pathway_group_suggestion import PaginatedPathwayGroupSuggestion
from iblai.models.paginated_pathway_suggestion import PaginatedPathwaySuggestion
from iblai.models.paginated_periodic_agent_list import PaginatedPeriodicAgentList
from iblai.models.paginated_periodic_agent_log_list import PaginatedPeriodicAgentLogList
from iblai.models.paginated_platform_invitation import PaginatedPlatformInvitation
from iblai.models.paginated_platform_license import PaginatedPlatformLicense
from iblai.models.paginated_play_wright_script_list import PaginatedPlayWrightScriptList
from iblai.models.paginated_program_group_suggestion import PaginatedProgramGroupSuggestion
from iblai.models.paginated_program_invitation import PaginatedProgramInvitation
from iblai.models.paginated_program_license import PaginatedProgramLicense
from iblai.models.paginated_program_license_assignment import PaginatedProgramLicenseAssignment
from iblai.models.paginated_program_license_group_assignment import PaginatedProgramLicenseGroupAssignment
from iblai.models.paginated_program_suggestion import PaginatedProgramSuggestion
from iblai.models.paginated_rbac_group_list import PaginatedRbacGroupList
from iblai.models.paginated_rbac_policy_list import PaginatedRbacPolicyList
from iblai.models.paginated_rbac_role_list import PaginatedRbacRoleList
from iblai.models.paginated_retriever_document_embedding_list import PaginatedRetrieverDocumentEmbeddingList
from iblai.models.paginated_section_list import PaginatedSectionList
from iblai.models.paginated_skill import PaginatedSkill
from iblai.models.paginated_sub_section_list import PaginatedSubSectionList
from iblai.models.paginated_topic_statistics_response import PaginatedTopicStatisticsResponse
from iblai.models.paginated_training_list import PaginatedTrainingList
from iblai.models.paginated_unit_list import PaginatedUnitList
from iblai.models.paginated_user_app_list import PaginatedUserAppList
from iblai.models.paginated_user_edx_memory_list import PaginatedUserEdxMemoryList
from iblai.models.paginated_user_license import PaginatedUserLicense
from iblai.models.paginated_user_license_assignment import PaginatedUserLicenseAssignment
from iblai.models.paginated_user_license_group_assignment import PaginatedUserLicenseGroupAssignment
from iblai.models.paginated_voice_list import PaginatedVoiceList
from iblai.models.pagination import Pagination
from iblai.models.patched_bot_command import PatchedBotCommand
from iblai.models.patched_bot_create import PatchedBotCreate
from iblai.models.patched_call_configuration import PatchedCallConfiguration
from iblai.models.patched_conversations import PatchedConversations
from iblai.models.patched_course_creation_task_file import PatchedCourseCreationTaskFile
from iblai.models.patched_credential_request import PatchedCredentialRequest
from iblai.models.patched_data_set import PatchedDataSet
from iblai.models.patched_discord_config import PatchedDiscordConfig
from iblai.models.patched_discord_user_config import PatchedDiscordUserConfig
from iblai.models.patched_llm_credential_request import PatchedLLMCredentialRequest
from iblai.models.patched_mcp_server import PatchedMCPServer
from iblai.models.patched_media_resource import PatchedMediaResource
from iblai.models.patched_mentor_category_group_create import PatchedMentorCategoryGroupCreate
from iblai.models.patched_mentor_create import PatchedMentorCreate
from iblai.models.patched_notification import PatchedNotification
from iblai.models.patched_periodic_agent_create import PatchedPeriodicAgentCreate
from iblai.models.patched_platform_public_metadata import PatchedPlatformPublicMetadata
from iblai.models.patched_play_wright_script import PatchedPlayWrightScript
from iblai.models.patched_prompt import PatchedPrompt
from iblai.models.patched_prompt_prompt_visibility import PatchedPromptPromptVisibility
from iblai.models.patched_rbac_group import PatchedRbacGroup
from iblai.models.patched_rbac_policy import PatchedRbacPolicy
from iblai.models.patched_rbac_role import PatchedRbacRole
from iblai.models.patched_section import PatchedSection
from iblai.models.patched_skill_threshold import PatchedSkillThreshold
from iblai.models.patched_slack_config import PatchedSlackConfig
from iblai.models.patched_slack_user_config import PatchedSlackUserConfig
from iblai.models.patched_sub_section import PatchedSubSection
from iblai.models.patched_teams_config import PatchedTeamsConfig
from iblai.models.patched_training_create import PatchedTrainingCreate
from iblai.models.patched_unit import PatchedUnit
from iblai.models.patched_webex_config import PatchedWebexConfig
from iblai.models.patched_whatsapp_config import PatchedWhatsappConfig
from iblai.models.patched_whatsapp_user_config import PatchedWhatsappUserConfig
from iblai.models.pathway import Pathway
from iblai.models.pathway_completion_response import PathwayCompletionResponse
from iblai.models.pathway_create_update_request import PathwayCreateUpdateRequest
from iblai.models.pathway_delete_response import PathwayDeleteResponse
from iblai.models.pathway_enrollment import PathwayEnrollment
from iblai.models.pathway_enrollment_plus import PathwayEnrollmentPlus
from iblai.models.pathway_enrollment_request import PathwayEnrollmentRequest
from iblai.models.pathway_group_suggestion_create import PathwayGroupSuggestionCreate
from iblai.models.pathway_group_suggestion_detail import PathwayGroupSuggestionDetail
from iblai.models.pathway_self_enrollment_request import PathwaySelfEnrollmentRequest
from iblai.models.pathway_suggestion_bulk_create import PathwaySuggestionBulkCreate
from iblai.models.pathway_suggestion_create import PathwaySuggestionCreate
from iblai.models.pathway_suggestion_detail import PathwaySuggestionDetail
from iblai.models.per_learner_course_last_access_data import PerLearnerCourseLastAccessData
from iblai.models.per_learner_course_videos_watched import PerLearnerCourseVideosWatched
from iblai.models.per_learner_course_videos_watched_data import PerLearnerCourseVideosWatchedData
from iblai.models.per_learner_last_access import PerLearnerLastAccess
from iblai.models.per_learner_last_access_data import PerLearnerLastAccessData
from iblai.models.per_learner_time_spent_in_course_tree import PerLearnerTimeSpentInCourseTree
from iblai.models.performance_grades_per_course import PerformanceGradesPerCourse
from iblai.models.performance_grades_per_course_data import PerformanceGradesPerCourseData
from iblai.models.periodic_agent import PeriodicAgent
from iblai.models.periodic_agent_create import PeriodicAgentCreate
from iblai.models.periodic_agent_log import PeriodicAgentLog
from iblai.models.periodic_agent_log_status_enum import PeriodicAgentLogStatusEnum
from iblai.models.periodic_task import PeriodicTask
from iblai.models.perlearner_course_progress import PerlearnerCourseProgress
from iblai.models.perlearner_course_progress_data import PerlearnerCourseProgressData
from iblai.models.perlearner_engagement_videos_data import PerlearnerEngagementVideosData
from iblai.models.perlearner_engagement_videos_watched_per_course import PerlearnerEngagementVideosWatchedPerCourse
from iblai.models.perlearner_grade_summary import PerlearnerGradeSummary
from iblai.models.perlearner_grade_summary_data import PerlearnerGradeSummaryData
from iblai.models.perlearner_grade_with_cut_off import PerlearnerGradeWithCutOff
from iblai.models.perlearner_grade_with_cut_off_data import PerlearnerGradeWithCutOffData
from iblai.models.perlearner_grading_per_course_api import PerlearnerGradingPerCourseAPI
from iblai.models.perlearner_grading_per_course_api_data import PerlearnerGradingPerCourseAPIData
from iblai.models.perlearner_user_list import PerlearnerUserList
from iblai.models.perlearner_user_list_data import PerlearnerUserListData
from iblai.models.pie_chart_data import PieChartData
from iblai.models.pie_chart_segment import PieChartSegment
from iblai.models.pinned_message_create import PinnedMessageCreate
from iblai.models.pinned_message_get import PinnedMessageGet
from iblai.models.pinned_message_request import PinnedMessageRequest
from iblai.models.platform import Platform
from iblai.models.platform_api_key import PlatformApiKey
from iblai.models.platform_invitation_create import PlatformInvitationCreate
from iblai.models.platform_invitation_detail import PlatformInvitationDetail
from iblai.models.platform_invitation_redemption import PlatformInvitationRedemption
from iblai.models.platform_license_create import PlatformLicenseCreate
from iblai.models.platform_license_detail import PlatformLicenseDetail
from iblai.models.platform_license_update import PlatformLicenseUpdate
from iblai.models.platform_list import PlatformList
from iblai.models.platform_list_status_enum import PlatformListStatusEnum
from iblai.models.platform_public_metadata import PlatformPublicMetadata
from iblai.models.platform_skill_point_bulk_request import PlatformSkillPointBulkRequest
from iblai.models.platform_skill_point_bulk_response import PlatformSkillPointBulkResponse
from iblai.models.platform_skill_point_group_request import PlatformSkillPointGroupRequest
from iblai.models.platform_skill_point_request import PlatformSkillPointRequest
from iblai.models.platform_skill_point_response import PlatformSkillPointResponse
from iblai.models.platform_update_post_request import PlatformUpdatePostRequest
from iblai.models.play_wright_script import PlayWrightScript
from iblai.models.points_percentile import PointsPercentile
from iblai.models.predictive_analytics_request import PredictiveAnalyticsRequest
from iblai.models.predictive_analytics_response import PredictiveAnalyticsResponse
from iblai.models.preview_response import PreviewResponse
from iblai.models.previous_agent_status_enum import PreviousAgentStatusEnum
from iblai.models.product import Product
from iblai.models.product_table import ProductTable
from iblai.models.program import Program
from iblai.models.program_completion_response import ProgramCompletionResponse
from iblai.models.program_course_position import ProgramCoursePosition
from iblai.models.program_create_update_request import ProgramCreateUpdateRequest
from iblai.models.program_delete_response import ProgramDeleteResponse
from iblai.models.program_enrollment import ProgramEnrollment
from iblai.models.program_enrollment_plus import ProgramEnrollmentPlus
from iblai.models.program_enrollment_search_response import ProgramEnrollmentSearchResponse
from iblai.models.program_group_suggestion_create import ProgramGroupSuggestionCreate
from iblai.models.program_group_suggestion_detail import ProgramGroupSuggestionDetail
from iblai.models.program_invitation_create import ProgramInvitationCreate
from iblai.models.program_invitation_detail import ProgramInvitationDetail
from iblai.models.program_invitation_redemption import ProgramInvitationRedemption
from iblai.models.program_license_assignment_create import ProgramLicenseAssignmentCreate
from iblai.models.program_license_assignment_detail import ProgramLicenseAssignmentDetail
from iblai.models.program_license_create_detail import ProgramLicenseCreateDetail
from iblai.models.program_license_detail import ProgramLicenseDetail
from iblai.models.program_license_group_assignment_create import ProgramLicenseGroupAssignmentCreate
from iblai.models.program_license_group_assignment_detail import ProgramLicenseGroupAssignmentDetail
from iblai.models.program_license_update_detail import ProgramLicenseUpdateDetail
from iblai.models.program_metadata_request import ProgramMetadataRequest
from iblai.models.program_metadata_response import ProgramMetadataResponse
from iblai.models.program_review import ProgramReview
from iblai.models.program_review_info_response import ProgramReviewInfoResponse
from iblai.models.program_review_paginated_response import ProgramReviewPaginatedResponse
from iblai.models.program_review_request import ProgramReviewRequest
from iblai.models.program_search import ProgramSearch
from iblai.models.program_suggestion_bulk_create import ProgramSuggestionBulkCreate
from iblai.models.program_suggestion_create import ProgramSuggestionCreate
from iblai.models.program_suggestion_detail import ProgramSuggestionDetail
from iblai.models.program_type_enum import ProgramTypeEnum
from iblai.models.prompt import Prompt
from iblai.models.prompt_category import PromptCategory
from iblai.models.prompt_facet import PromptFacet
from iblai.models.prompt_search_response import PromptSearchResponse
from iblai.models.prompt_visibility_enum import PromptVisibilityEnum
from iblai.models.provider05c_enum import Provider05cEnum
from iblai.models.provider637_enum import Provider637Enum
from iblai.models.provider63a_enum import Provider63aEnum
from iblai.models.provider_association_stripe_callback_retrieve404_response import ProviderAssociationStripeCallbackRetrieve404Response
from iblai.models.question_card_tag import QuestionCardTag
from iblai.models.question_request import QuestionRequest
from iblai.models.question_response import QuestionResponse
from iblai.models.rating_enum import RatingEnum
from iblai.models.rating_record import RatingRecord
from iblai.models.rbac_base_role import RbacBaseRole
from iblai.models.rbac_group import RbacGroup
from iblai.models.rbac_platform import RbacPlatform
from iblai.models.rbac_policy import RbacPolicy
from iblai.models.rbac_policy_group import RbacPolicyGroup
from iblai.models.rbac_role import RbacRole
from iblai.models.rbac_user import RbacUser
from iblai.models.recently_accessed_mentor import RecentlyAccessedMentor
from iblai.models.recipient import Recipient
from iblai.models.recommend_course_block import RecommendCourseBlock
from iblai.models.recommend_course_response import RecommendCourseResponse
from iblai.models.recommendation_search_api import RecommendationSearchAPI
from iblai.models.recommended_courses_response import RecommendedCoursesResponse
from iblai.models.redirect_token_request import RedirectTokenRequest
from iblai.models.redirect_token_response import RedirectTokenResponse
from iblai.models.related_text import RelatedText
from iblai.models.report_create import ReportCreate
from iblai.models.report_data import ReportData
from iblai.models.report_detail import ReportDetail
from iblai.models.report_list import ReportList
from iblai.models.report_request import ReportRequest
from iblai.models.report_status import ReportStatus
from iblai.models.reported_role import ReportedRole
from iblai.models.reported_role_create_update_request import ReportedRoleCreateUpdateRequest
from iblai.models.reported_skill import ReportedSkill
from iblai.models.request_data_variable import RequestDataVariable
from iblai.models.resource import Resource
from iblai.models.resource_completion import ResourceCompletion
from iblai.models.resource_completion_request import ResourceCompletionRequest
from iblai.models.resource_create_update import ResourceCreateUpdate
from iblai.models.resource_delete_response import ResourceDeleteResponse
from iblai.models.resource_point import ResourcePoint
from iblai.models.resource_scrapped_data import ResourceScrappedData
from iblai.models.resource_scrapped_data_status import ResourceScrappedDataStatus
from iblai.models.resource_scrapped_data_status_enum import ResourceScrappedDataStatusEnum
from iblai.models.response_data_variable import ResponseDataVariable
from iblai.models.retreiver_train_view_request import RetreiverTrainViewRequest
from iblai.models.retreiver_train_view_response import RetreiverTrainViewResponse
from iblai.models.retrieve_task import RetrieveTask
from iblai.models.retriever_document_embedding import RetrieverDocumentEmbedding
from iblai.models.retriever_document_embedding_access import RetrieverDocumentEmbeddingAccess
from iblai.models.retriever_document_embedding_request import RetrieverDocumentEmbeddingRequest
from iblai.models.retriever_document_embedding_training_status import RetrieverDocumentEmbeddingTrainingStatus
from iblai.models.retriever_request_search import RetrieverRequestSearch
from iblai.models.retriever_request_search_document import RetrieverRequestSearchDocument
from iblai.models.retriever_response_search import RetrieverResponseSearch
from iblai.models.reuest_data_variable_list import ReuestDataVariableList
from iblai.models.revenue_by_product import RevenueByProduct
from iblai.models.role import Role
from iblai.models.role_create_update_request import RoleCreateUpdateRequest
from iblai.models.run_mentor_eval import RunMentorEval
from iblai.models.scan_webhook_request import ScanWebhookRequest
from iblai.models.scan_webhook_response import ScanWebhookResponse
from iblai.models.section import Section
from iblai.models.section_with_children import SectionWithChildren
from iblai.models.seed_mentors_view import SeedMentorsView
from iblai.models.send_notification import SendNotification
from iblai.models.send_response import SendResponse
from iblai.models.sentiment_summary import SentimentSummary
from iblai.models.session_browser_screenshot import SessionBrowserScreenshot
from iblai.models.session_detail import SessionDetail
from iblai.models.session_memory_storage import SessionMemoryStorage
from iblai.models.shell_logs import ShellLogs
from iblai.models.skill import Skill
from iblai.models.skill_create_update_request import SkillCreateUpdateRequest
from iblai.models.skill_detail import SkillDetail
from iblai.models.skill_info import SkillInfo
from iblai.models.skill_threshold import SkillThreshold
from iblai.models.slack_config import SlackConfig
from iblai.models.slack_user_config import SlackUserConfig
from iblai.models.slack_webhook import SlackWebhook
from iblai.models.spaced_repetition_learning_path import SpacedRepetitionLearningPath
from iblai.models.spaced_repetition_question_stats import SpacedRepetitionQuestionStats
from iblai.models.star_mentor import StarMentor
from iblai.models.state_enum import StateEnum
from iblai.models.status6ee_enum import Status6eeEnum
from iblai.models.step import Step
from iblai.models.step_status_enum import StepStatusEnum
from iblai.models.stripe_billing_page_identifier_response import StripeBillingPageIdentifierResponse
from iblai.models.stripe_checkout_session_request import StripeCheckoutSessionRequest
from iblai.models.stripe_checkout_session_request_mode_enum import StripeCheckoutSessionRequestModeEnum
from iblai.models.stripe_checkout_session_response import StripeCheckoutSessionResponse
from iblai.models.stripe_context import StripeContext
from iblai.models.stripe_customer_portal_request import StripeCustomerPortalRequest
from iblai.models.stripe_customer_portal_response import StripeCustomerPortalResponse
from iblai.models.stripe_local_product import StripeLocalProduct
from iblai.models.stripe_new_user_tenant_launch_request import StripeNewUserTenantLaunchRequest
from iblai.models.stripe_subscription_renewal_request import StripeSubscriptionRenewalRequest
from iblai.models.stripe_subscription_renewal_response import StripeSubscriptionRenewalResponse
from iblai.models.stt_provider_enum import SttProviderEnum
from iblai.models.student_chat_message import StudentChatMessage
from iblai.models.styles_view import StylesView
from iblai.models.sub_section import SubSection
from iblai.models.sub_section_with_children import SubSectionWithChildren
from iblai.models.sub_time_child import SubTimeChild
from iblai.models.summary import Summary
from iblai.models.tags_view import TagsView
from iblai.models.target_system_enum import TargetSystemEnum
from iblai.models.task_view import TaskView
from iblai.models.teams_config import TeamsConfig
from iblai.models.teams_webhook import TeamsWebhook
from iblai.models.template_mentor import TemplateMentor
from iblai.models.tenant_launch_error import TenantLaunchError
from iblai.models.tenant_launch_failed import TenantLaunchFailed
from iblai.models.tenant_launch_request import TenantLaunchRequest
from iblai.models.tenant_launch_response import TenantLaunchResponse
from iblai.models.tenant_mentor_traces import TenantMentorTraces
from iblai.models.theme_enum import ThemeEnum
from iblai.models.time_child_data import TimeChildData
from iblai.models.time_detail import TimeDetail
from iblai.models.time_detail_child import TimeDetailChild
from iblai.models.time_detail_data import TimeDetailData
from iblai.models.time_spent_by_users_in_course import TimeSpentByUsersInCourse
from iblai.models.time_spent_by_users_in_course_data import TimeSpentByUsersInCourseData
from iblai.models.time_spent_per_course import TimeSpentPerCourse
from iblai.models.time_spent_per_course_data import TimeSpentPerCourseData
from iblai.models.time_spent_per_user_response import TimeSpentPerUserResponse
from iblai.models.time_spent_update_request import TimeSpentUpdateRequest
from iblai.models.time_spent_update_response import TimeSpentUpdateResponse
from iblai.models.token_proxy_input import TokenProxyInput
from iblai.models.token_proxy_output import TokenProxyOutput
from iblai.models.token_proxy_output_serializer_data import TokenProxyOutputSerializerData
from iblai.models.token_proxy_user import TokenProxyUser
from iblai.models.tones_view import TonesView
from iblai.models.tool_response import ToolResponse
from iblai.models.topic_model import TopicModel
from iblai.models.topic_record import TopicRecord
from iblai.models.topic_statistics import TopicStatistics
from iblai.models.topic_statistics_response import TopicStatisticsResponse
from iblai.models.topic_summary_view import TopicSummaryView
from iblai.models.train_chat_session_document_view import TrainChatSessionDocumentView
from iblai.models.train_chat_session_document_view_request import TrainChatSessionDocumentViewRequest
from iblai.models.train_document_view_request import TrainDocumentViewRequest
from iblai.models.train_document_view_response import TrainDocumentViewResponse
from iblai.models.training import Training
from iblai.models.training_create import TrainingCreate
from iblai.models.training_status_enum import TrainingStatusEnum
from iblai.models.transport_enum import TransportEnum
from iblai.models.trend_entry import TrendEntry
from iblai.models.trigger_request import TriggerRequest
from iblai.models.trigger_response import TriggerResponse
from iblai.models.tts_provider_enum import TtsProviderEnum
from iblai.models.type_c42_enum import TypeC42Enum
from iblai.models.unit import Unit
from iblai.models.unit_with_children import UnitWithChildren
from iblai.models.uploaded_image import UploadedImage
from iblai.models.use_main_creds import UseMainCreds
from iblai.models.user_all_chat_memory_view import UserAllChatMemoryView
from iblai.models.user_app import UserApp
from iblai.models.user_catalog_item_memory_view import UserCatalogItemMemoryView
from iblai.models.user_chat_by_period import UserChatByPeriod
from iblai.models.user_chat_feedback import UserChatFeedback
from iblai.models.user_chat_feedback_count import UserChatFeedbackCount
from iblai.models.user_chat_memory_status_request_view import UserChatMemoryStatusRequestView
from iblai.models.user_chat_memory_status_view import UserChatMemoryStatusView
from iblai.models.user_chat_memory_update_view import UserChatMemoryUpdateView
from iblai.models.user_count_record import UserCountRecord
from iblai.models.user_delete_api_error import UserDeleteAPIError
from iblai.models.user_delete_api_request import UserDeleteAPIRequest
from iblai.models.user_delete_api_response import UserDeleteAPIResponse
from iblai.models.user_edx_memory import UserEdxMemory
from iblai.models.user_info import UserInfo
from iblai.models.user_license_assignment_create import UserLicenseAssignmentCreate
from iblai.models.user_license_assignment_detail import UserLicenseAssignmentDetail
from iblai.models.user_license_create import UserLicenseCreate
from iblai.models.user_license_detail import UserLicenseDetail
from iblai.models.user_license_group_assignment_create import UserLicenseGroupAssignmentCreate
from iblai.models.user_license_group_assignment_detail import UserLicenseGroupAssignmentDetail
from iblai.models.user_license_update import UserLicenseUpdate
from iblai.models.user_memory_context_request import UserMemoryContextRequest
from iblai.models.user_memory_context_response import UserMemoryContextResponse
from iblai.models.user_metric import UserMetric
from iblai.models.user_metrics_response import UserMetricsResponse
from iblai.models.user_platform_link import UserPlatformLink
from iblai.models.user_platform_management_list_view_get_response import UserPlatformManagementListViewGetResponse
from iblai.models.user_platform_view_post_request import UserPlatformViewPostRequest
from iblai.models.user_proxy_bulk_request import UserProxyBulkRequest
from iblai.models.user_proxy_get_response import UserProxyGetResponse
from iblai.models.user_proxy_post_request import UserProxyPostRequest
from iblai.models.user_proxy_post_response import UserProxyPostResponse
from iblai.models.user_search_response import UserSearchResponse
from iblai.models.user_search_view_get_response import UserSearchViewGetResponse
from iblai.models.user_sentiment_count_view import UserSentimentCountView
from iblai.models.user_skill import UserSkill
from iblai.models.user_skill_points_percentile import UserSkillPointsPercentile
from iblai.models.user_trend_by_period import UserTrendByPeriod
from iblai.models.validate_source_response import ValidateSourceResponse
from iblai.models.value import Value
from iblai.models.value_data import ValueData
from iblai.models.vector_result import VectorResult
from iblai.models.verify_gcp_market_place_failed_response import VerifyGCPMarketPlaceFailedResponse
from iblai.models.verify_gcp_market_place_request import VerifyGCPMarketPlaceRequest
from iblai.models.verify_gcp_market_place_response import VerifyGCPMarketPlaceResponse
from iblai.models.video_block import VideoBlock
from iblai.models.video_caption import VideoCaption
from iblai.models.video_engagement_per_course import VideoEngagementPerCourse
from iblai.models.video_engagement_per_course_data import VideoEngagementPerCourseData
from iblai.models.videos_count import VideosCount
from iblai.models.videos_count_data import VideosCountData
from iblai.models.videos_in_course_summary import VideosInCourseSummary
from iblai.models.videos_in_course_summary_data import VideosInCourseSummaryData
from iblai.models.videos_specific_course import VideosSpecificCourse
from iblai.models.videos_specific_course_data import VideosSpecificCourseData
from iblai.models.videos_watched_sub_section import VideosWatchedSubSection
from iblai.models.voice import Voice
from iblai.models.watched_videos_per_course import WatchedVideosPerCourse
from iblai.models.watched_videos_per_course_data import WatchedVideosPerCourseData
from iblai.models.watched_videos_per_user import WatchedVideosPerUser
from iblai.models.watched_videos_per_user_data import WatchedVideosPerUserData
from iblai.models.web_resource import WebResource
from iblai.models.web_resource_card import WebResourceCard
from iblai.models.web_resources_query import WebResourcesQuery
from iblai.models.webex_config import WebexConfig
from iblai.models.webex_webhook import WebexWebhook
from iblai.models.what_app_web_hook import WhatAppWebHook
from iblai.models.whatsapp_config import WhatsappConfig
from iblai.models.whatsapp_user_config import WhatsappUserConfig
from iblai.models.whitelisted_domain import WhitelistedDomain
