# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.notification_api import NotificationApi


class TestNotificationApi(unittest.TestCase):
    """NotificationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotificationApi()

    def tearDown(self) -> None:
        pass

    def test_notification_v1_orgs_notifications_bulk_update_partial_update(self) -> None:
        """Test case for notification_v1_orgs_notifications_bulk_update_partial_update

        """
        pass

    def test_notification_v1_orgs_notifications_retrieve(self) -> None:
        """Test case for notification_v1_orgs_notifications_retrieve

        """
        pass

    def test_notification_v1_orgs_notifications_update(self) -> None:
        """Test case for notification_v1_orgs_notifications_update

        """
        pass

    def test_notification_v1_orgs_users_notifications_bulk_update_partial_update(self) -> None:
        """Test case for notification_v1_orgs_users_notifications_bulk_update_partial_update

        """
        pass

    def test_notification_v1_orgs_users_notifications_count_retrieve(self) -> None:
        """Test case for notification_v1_orgs_users_notifications_count_retrieve

        """
        pass

    def test_notification_v1_orgs_users_notifications_destroy(self) -> None:
        """Test case for notification_v1_orgs_users_notifications_destroy

        """
        pass

    def test_notification_v1_orgs_users_notifications_retrieve(self) -> None:
        """Test case for notification_v1_orgs_users_notifications_retrieve

        """
        pass

    def test_notification_v1_orgs_users_notifications_update(self) -> None:
        """Test case for notification_v1_orgs_users_notifications_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
