# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.media_resources_api import MediaResourcesApi


class TestMediaResourcesApi(unittest.TestCase):
    """MediaResourcesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MediaResourcesApi()

    def tearDown(self) -> None:
        pass

    def test_media_orgs_users_media_media_resources_by_item_retrieve(self) -> None:
        """Test case for media_orgs_users_media_media_resources_by_item_retrieve

        """
        pass

    def test_media_orgs_users_media_media_resources_create(self) -> None:
        """Test case for media_orgs_users_media_media_resources_create

        """
        pass

    def test_media_orgs_users_media_media_resources_destroy(self) -> None:
        """Test case for media_orgs_users_media_media_resources_destroy

        """
        pass

    def test_media_orgs_users_media_media_resources_list(self) -> None:
        """Test case for media_orgs_users_media_media_resources_list

        """
        pass

    def test_media_orgs_users_media_media_resources_partial_update(self) -> None:
        """Test case for media_orgs_users_media_media_resources_partial_update

        """
        pass

    def test_media_orgs_users_media_media_resources_retrieve(self) -> None:
        """Test case for media_orgs_users_media_media_resources_retrieve

        """
        pass

    def test_media_orgs_users_media_media_resources_search_retrieve(self) -> None:
        """Test case for media_orgs_users_media_media_resources_search_retrieve

        """
        pass

    def test_media_orgs_users_media_media_resources_update(self) -> None:
        """Test case for media_orgs_users_media_media_resources_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
