# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class PlatformListStatusEnum(int, Enum):
    """
    * `-2` - FAILED * `-1` - TERMINATED * `0` - PENDING * `1` - BUILDING * `2` - RUNNING * `3` - PAUSED * `4` - STOPPING * `5` - STOPPED * `6` - REPAIR
    """

    """
    allowed enum values
    """
    NUMBER_MINUS_2 = -2
    NUMBER_MINUS_1 = -1
    NUMBER_0 = 0
    NUMBER_1 = 1
    NUMBER_2 = 2
    NUMBER_3 = 3
    NUMBER_4 = 4
    NUMBER_5 = 5
    NUMBER_6 = 6

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PlatformListStatusEnum from a JSON string"""
        return cls(json.loads(json_str))


