# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.perlearner_user_list import PerlearnerUserList

class TestPerlearnerUserList(unittest.TestCase):
    """PerlearnerUserList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PerlearnerUserList:
        """Test PerlearnerUserList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PerlearnerUserList`
        """
        model = PerlearnerUserList()
        if include_optional:
            return PerlearnerUserList(
                data = [
                    iblai.models.perlearner_user_list_data.PerlearnerUserListData(
                        username = '', 
                        full_name = '', 
                        enrollments = 56, 
                        completions = 56, 
                        last_active = '', 
                        time_spent = '', 
                        engagement_index = 1.337, 
                        performance_index = 1.337, )
                    ],
                pagination = iblai.models.pagination.Pagination(
                    total_items = 56, 
                    current_page = 56, 
                    per_page = 56, 
                    total_pages = 56, )
            )
        else:
            return PerlearnerUserList(
                pagination = iblai.models.pagination.Pagination(
                    total_items = 56, 
                    current_page = 56, 
                    per_page = 56, 
                    total_pages = 56, ),
        )
        """

    def testPerlearnerUserList(self):
        """Test PerlearnerUserList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
