# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.question_response import QuestionResponse

class TestQuestionResponse(unittest.TestCase):
    """QuestionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> QuestionResponse:
        """Test QuestionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `QuestionResponse`
        """
        model = QuestionResponse()
        if include_optional:
            return QuestionResponse(
                questions = [
                    iblai.models.llm_question.LLMQuestion(
                        text = '', 
                        difficulty_level = 1, 
                        options = [
                            iblai.models.answer.Answer(
                                text = '', 
                                is_correct = True, )
                            ], )
                    ]
            )
        else:
            return QuestionResponse(
                questions = [
                    iblai.models.llm_question.LLMQuestion(
                        text = '', 
                        difficulty_level = 1, 
                        options = [
                            iblai.models.answer.Answer(
                                text = '', 
                                is_correct = True, )
                            ], )
                    ],
        )
        """

    def testQuestionResponse(self):
        """Test QuestionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
