# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.credentials_api import CredentialsApi


class TestCredentialsApi(unittest.TestCase):
    """CredentialsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CredentialsApi()

    def tearDown(self) -> None:
        pass

    def test_credentials_orgs_users_assertions_bulk_create(self) -> None:
        """Test case for credentials_orgs_users_assertions_bulk_create

        """
        pass

    def test_credentials_orgs_users_assertions_create(self) -> None:
        """Test case for credentials_orgs_users_assertions_create

        """
        pass

    def test_credentials_orgs_users_assertions_over_time_retrieve(self) -> None:
        """Test case for credentials_orgs_users_assertions_over_time_retrieve

        """
        pass

    def test_credentials_orgs_users_assertions_retrieve(self) -> None:
        """Test case for credentials_orgs_users_assertions_retrieve

        """
        pass

    def test_credentials_orgs_users_assertions_retrieve2(self) -> None:
        """Test case for credentials_orgs_users_assertions_retrieve2

        """
        pass

    def test_credentials_orgs_users_assertions_retrieve3(self) -> None:
        """Test case for credentials_orgs_users_assertions_retrieve3

        """
        pass

    def test_credentials_orgs_users_assertions_update(self) -> None:
        """Test case for credentials_orgs_users_assertions_update

        """
        pass

    def test_credentials_orgs_users_course_assertions_over_time_retrieve(self) -> None:
        """Test case for credentials_orgs_users_course_assertions_over_time_retrieve

        """
        pass

    def test_credentials_orgs_users_course_credentials_list(self) -> None:
        """Test case for credentials_orgs_users_course_credentials_list

        """
        pass

    def test_credentials_orgs_users_create(self) -> None:
        """Test case for credentials_orgs_users_create

        """
        pass

    def test_credentials_orgs_users_credentials_over_time_retrieve(self) -> None:
        """Test case for credentials_orgs_users_credentials_over_time_retrieve

        """
        pass

    def test_credentials_orgs_users_destroy(self) -> None:
        """Test case for credentials_orgs_users_destroy

        """
        pass

    def test_credentials_orgs_users_issuers_authority_create(self) -> None:
        """Test case for credentials_orgs_users_issuers_authority_create

        """
        pass

    def test_credentials_orgs_users_issuers_create(self) -> None:
        """Test case for credentials_orgs_users_issuers_create

        """
        pass

    def test_credentials_orgs_users_issuers_destroy(self) -> None:
        """Test case for credentials_orgs_users_issuers_destroy

        """
        pass

    def test_credentials_orgs_users_issuers_retrieve(self) -> None:
        """Test case for credentials_orgs_users_issuers_retrieve

        """
        pass

    def test_credentials_orgs_users_issuers_retrieve2(self) -> None:
        """Test case for credentials_orgs_users_issuers_retrieve2

        """
        pass

    def test_credentials_orgs_users_issuers_update(self) -> None:
        """Test case for credentials_orgs_users_issuers_update

        """
        pass

    def test_credentials_orgs_users_retrieve(self) -> None:
        """Test case for credentials_orgs_users_retrieve

        """
        pass

    def test_credentials_orgs_users_retrieve2(self) -> None:
        """Test case for credentials_orgs_users_retrieve2

        """
        pass

    def test_credentials_orgs_users_update(self) -> None:
        """Test case for credentials_orgs_users_update

        """
        pass

    def test_credentials_public_assertions_retrieve(self) -> None:
        """Test case for credentials_public_assertions_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
