# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.full_course import FullCourse

class TestFullCourse(unittest.TestCase):
    """FullCourse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FullCourse:
        """Test FullCourse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FullCourse`
        """
        model = FullCourse()
        if include_optional:
            return FullCourse(
                id = 56,
                name = '',
                run = '',
                number = '',
                description = '',
                xblock_id = '',
                task = 56,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                sections = [
                    iblai.models.section_with_children.SectionWithChildren(
                        id = 56, 
                        course = 56, 
                        display_name = '', 
                        status = null, 
                        subsections = [
                            iblai.models.sub_section_with_children.SubSectionWithChildren(
                                id = 56, 
                                section = 56, 
                                display_name = '', 
                                status = null, 
                                units = [
                                    iblai.models.unit_with_children.UnitWithChildren(
                                        id = 56, 
                                        subsection = 56, 
                                        display_name = '', 
                                        status = null, 
                                        type = 'tutorial', 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        components = [
                                            iblai.models.component_block.ComponentBlock(
                                                id = 56, 
                                                unit = 56, 
                                                display_name = '', 
                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], )
                                    ], 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return FullCourse(
                id = 56,
                name = '',
                run = '',
                number = '',
                xblock_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                sections = [
                    iblai.models.section_with_children.SectionWithChildren(
                        id = 56, 
                        course = 56, 
                        display_name = '', 
                        status = null, 
                        subsections = [
                            iblai.models.sub_section_with_children.SubSectionWithChildren(
                                id = 56, 
                                section = 56, 
                                display_name = '', 
                                status = null, 
                                units = [
                                    iblai.models.unit_with_children.UnitWithChildren(
                                        id = 56, 
                                        subsection = 56, 
                                        display_name = '', 
                                        status = null, 
                                        type = 'tutorial', 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        components = [
                                            iblai.models.component_block.ComponentBlock(
                                                id = 56, 
                                                unit = 56, 
                                                display_name = '', 
                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], )
                                    ], 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testFullCourse(self):
        """Test FullCourse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
