# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.patched_call_configuration import PatchedCallConfiguration

class TestPatchedCallConfiguration(unittest.TestCase):
    """PatchedCallConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedCallConfiguration:
        """Test PatchedCallConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedCallConfiguration`
        """
        model = PatchedCallConfiguration()
        if include_optional:
            return PatchedCallConfiguration(
                id = 56,
                mentor = 56,
                mode = 'realtime',
                tts_provider = 'openai',
                stt_provider = 'openai',
                llm_provider = 'openai',
                use_function_calling_for_rag = True,
                google_voice = iblai.models.voice.Voice(
                    id = 56, 
                    name = '', 
                    provider = 'openai', 
                    language = '', 
                    description = '', 
                    audio_url = '', ),
                openai_voice = iblai.models.voice.Voice(
                    id = 56, 
                    name = '', 
                    provider = 'openai', 
                    language = '', 
                    description = '', 
                    audio_url = '', ),
                openai_voice_id = 56,
                google_voice_id = 56,
                enable_video = True,
                platform_key = ''
            )
        else:
            return PatchedCallConfiguration(
        )
        """

    def testPatchedCallConfiguration(self):
        """Test PatchedCallConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
